<?php
/**
 * All the core functions
 *
 * @package Live Composer - WooCommerce integration
 */

// Prevent direct access to the file.
if ( ! defined( 'ABSPATH' ) ) {
	header( 'HTTP/1.0 403 Forbidden' );
	exit;
}

/**
 * Add a class 'woocommerce' for Edit mode
 *
 * @param array $classes One or more classes to add to the class list.
 *
 * @return array
 */
function lcwoo_add_class( $classes ) {

	global $dslc_active;

	if ( $dslc_active ) {
		if ( isset( $_GET['page_id'] ) ) {
			$dslc_template = get_post_meta( get_the_ID(), 'dslc_template_for', true );

			if ( 'product' === $dslc_template || 'product_archive' === $dslc_template || 'woo-shop' === $dslc_template ) {
				$classes[] = 'woocommerce';
			}
		}
	} elseif ( 'dslc_templates' === get_post_type() ) {
		$id = get_the_ID();
		$dslc_template = get_post_meta( get_the_ID(), 'dslc_template_for', true );

		if ( 'product' === $dslc_template || 'product_archive' === $dslc_template || 'woo-shop' === $dslc_template ) {
			$classes[] = 'woocommerce';
		}
	}

	return $classes;
}
add_filter( 'body_class', 'lcwoo_add_class' );

/**
 * Add a class 'product' for Edit mode
 *
 * @param array $classes One or more classes to add to the class list.
 *
 * @return array
 */
function lcwoo_add_class_for_listing( $classes ) {

	global $dslc_active;

	if ( $dslc_active && 'product' === get_post_type() ) {
		$classes[] = 'product';
	}

	return $classes;
}
add_filter( 'post_class', 'lcwoo_add_class_for_listing' );

/**
 * Disable module 'Product Woo' in LC
 */
function lcwoo_disable_woocommerce_module() {
	dslc_unregister_module( 'DSLC_WooCommerce_Products' );
}
add_action( 'dslc_hook_unregister_modules', 'lcwoo_disable_woocommerce_module' );

/**
 * Shop messages
 */
function lcwoo_shop_messages() {
	if ( ! is_checkout() ) {
		echo wp_kses_post( lcwooo_do_shortcode( 'woocommerce_messages' ) );
	}
}
add_action( 'lcwoo_content_top', 'lcwoo_shop_messages', 15 );

/**
 * Add Shop Messages
 */
function lcwoo_shop_messages_add_top() {
	if ( is_cart() ) {
		do_action( 'lcwoo_content_top' );
	}
}
add_action( 'wp_head', 'lcwoo_shop_messages_add_top' );

/**
 * Call a shortcode function by tag name.
 *
 * @param string $tag     The shortcode whose function to call.
 * @param array  $atts    The attributes to pass to the shortcode function. Optional.
 * @param array  $content The shortcode's content. Default is null (none).
 *
 * @return string|bool False on failure, the result of the shortcode on success.
 */
function lcwooo_do_shortcode( $tag, array $atts = array(), $content = null ) {
	global $shortcode_tags;

	if ( ! isset( $shortcode_tags[ $tag ] ) ) {
		return false;
	}

	return call_user_func( $shortcode_tags[ $tag ], $atts, $content, $tag );
}

/**
 * Add Design for Pages
 */
function lcwoo_add_design_for_pages() {

	$woo_cart_page_id = get_option( 'woocommerce_cart_page_id' );
	$woo_checkout_page_id = get_option( 'woocommerce_checkout_page_id' );
	$woo_myaccount_page_id = get_option( 'woocommerce_myaccount_page_id' );

	if ( false === get_option( 'lcwoo_cart_page_flag' ) ) {
		require_once( LCWOO_INTEGRATION_PLUGIN_DIR.'includes/cart/design/page/dslc-code-cart.php' );
		add_option( 'lcwoo_cart_page_flag', '1' );
	}

	if ( false === get_option( 'lcwoo_checkout_page_flag' ) ) {
		require_once( LCWOO_INTEGRATION_PLUGIN_DIR.'includes/checkout/design/page/dslc-code-checkout.php' );
		add_option( 'lcwoo_checkout_page_flag', '1' );
	}

	if ( false === get_option( 'lcwoo_myaccount_page_flag' ) ) {
		require_once( LCWOO_INTEGRATION_PLUGIN_DIR.'includes/account/design/page/dslc-code-account.php' );
		add_option( 'lcwoo_myaccount_page_flag', '1' );
	}
}
add_action( 'admin_footer', 'lcwoo_add_design_for_pages' );

/**
 * Create default Woo Product Template in the LiveComposer Templates Section
 */
function lcwoo_create_product_template() {

	if ( false === get_option( 'lcwoo_templates' ) ) {

		$default_templates = array(
			'product' => array(
				'type' => 'product',
				'title' => 'Woo Product',
				'slug' => 'woo-product',
			),
			'shop' => array(
				'type' => 'woo-shop',
				'title' => 'Woo Shop',
				'slug' => 'woo-shop',
			),
			'listing' => array(
				'type' => 'product_archive',
				'title' => 'Woo Listing',
				'slug' => 'product_archive',
			),
		);

		add_option( 'lcwoo_templates', $default_templates );
	}

	if ( false === get_option( 'lcwoo_templates_flag' ) ) {

		global $wpdb;
		$woo_templates = ( $wpdb->get_results( "SELECT *  FROM `".$wpdb->prefix."posts` WHERE `post_type`='dslc_templates'", 'ARRAY_A' ) );
		$woo_template_found = false;

		$default_templates = get_option( 'lcwoo_templates' );

		foreach ( $default_templates as $template_key => $template ) {

			foreach ( $woo_templates as $woo_template ) {
				if ( $template['type'] === get_post_meta( $woo_template['ID'], 'dslc_template_for', true ) ) {
					$woo_template_found = true;
					break;
				}
			}

			if ( ! $woo_template_found ) {
				$woo = array(
					'post_title' => $template['title'],
					'post_name' => $template['slug'],
					'post_type'  => 'dslc_templates',
					'post_status'  => 'publish',
					'ping_status'  => 'closed',
				);
				$post_id = wp_insert_post( $woo );
				add_metadata( 'post', $post_id, 'dslc_template_for', $template['type'], true );
				add_metadata( 'post', $post_id, 'dslc_template_base', 'custom', true );
				add_metadata( 'post', $post_id, 'dslc_template_type', 'default', true );

				if ( 'product' === $template['type'] ) {
					require_once( LCWOO_INTEGRATION_PLUGIN_DIR.'includes/product/design/dslc-code-product.php' );
				} elseif ( 'woo-shop' === $template['type'] ) {
					require_once( LCWOO_INTEGRATION_PLUGIN_DIR.'includes/shop/design/page/dslc-code-shop.php' );
				} elseif ( 'product_archive' === $template['type'] ) {
					require_once( LCWOO_INTEGRATION_PLUGIN_DIR.'includes/shop/design/dslc-code-listing.php' );
				}
			}
		}

		add_option( 'lcwoo_templates_flag', '1' );
	}
}
add_action( 'admin_init', 'lcwoo_create_product_template' );

/**
 * Include Templates
 *
 * @param string $template Get current template.
 */
function lcwoo_include_templates( $template ) {
	if ( is_shop() ) {
		$template = LCWOO_INTEGRATION_PLUGIN_DIR.'includes/shop/templates/page/shop.php';
	} elseif ( is_product_category() || is_product_tag() ) {
		$template = LCWOO_INTEGRATION_PLUGIN_DIR.'includes/shop/templates/listing.php';
	}

	return $template;
}
add_filter( 'template_include', 'lcwoo_include_templates', 99 );

/**
 * Add Woo Template into the list of post Templates in the Live Composer
 * WordPress Admin > Appearance > Templates
 *
 * @param array $template Add New Template.
 */
function lcwoo_enable_product_template( $template ) {

	$template['product'] = 'Woo Product';
	$template['woo-shop'] = 'Woo Shop';

	return $template;

} add_filter( 'dslc_post_templates_post_types', 'lcwoo_enable_product_template' );
