<?php
/**
 * Module Image
 *
 * @package Live Composer - WooCommerce integration
 */

// Prevent direct access to the file.
if ( ! defined( 'ABSPATH' ) ) {
	header( 'HTTP/1.0 403 Forbidden' );
	exit;
}

/**
 * Module Class
 */
class LCWoo_Image extends DSLC_Module {

	/**
	 * Unique module id
	 *
	 * @var string
	 */
	var $module_id;

	/**
	 * Module label to show in the page builder
	 *
	 * @var string
	 */
	var $module_title;

	/**
	 * Module icon name (FontAwesome)
	 *
	 * @var string
	 */
	var $module_icon;

	/**
	 * Section in the modules panel that includes this module
	 *
	 * @var string
	 */
	var $module_category;

	/**
	 * Exclude from main listing
	 *
	 * @var string
	 */
	var $exclude_from_main_listing;

	/**
	 * Construct
	 */
	function __construct() {

		$this->module_id = 'LCWoo_Image';
		$this->module_title = __( 'Images', 'lc-woo-integration' );
		$this->module_icon = 'picture';
		$this->module_category = 'Woo Product';
		$this->exclude_from_main_listing = true;
	}

	/**
	 * Options
	 */
	function options() {

		$options = array(

			array(
				'label' => __( 'Show On', 'lc-woo-integration' ),
				'id' => 'css_show_on',
				'std' => 'desktop tablet phone',
				'type' => 'checkbox',
				'choices' => array(
					array(
						'label' => __( 'Desktop', 'lc-woo-integration' ),
						'value' => 'desktop',
					),
					array(
						'label' => __( 'Tablet', 'lc-woo-integration' ),
						'value' => 'tablet',
					),
					array(
						'label' => __( 'Phone', 'lc-woo-integration' ),
						'value' => 'phone',
					),
				),
			),

			/**
			 * Styling
			 */

			array(
				'label' => __( 'Align', 'lc-woo-integration' ),
				'id' => 'css_align',
				'std' => 'center',
				'type' => 'select',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.images',
				'affect_on_change_rule' => 'text-align',
				'section' => 'styling',
				'choices' => array(
					array(
						'label' => __( 'Left', 'lc-woo-integration' ),
						'value' => 'left',
					),
					array(
						'label' => __( 'Center', 'lc-woo-integration' ),
						'value' => 'center',
					),
					array(
						'label' => __( 'Right', 'lc-woo-integration' ),
						'value' => 'right',
					),
					array(
						'label' => __( 'Justify', 'lc-woo-integration' ),
						'value' => 'justify',
					),
				),
			),
			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_bg_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.images',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
			),
			array(
				'label' => __( 'Border Color', 'lc-woo-integration' ),
				'id' => 'css_border_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.images',
				'affect_on_change_rule' => 'border-color',
				'section' => 'styling',
			),
			array(
				'label' => __( 'Border Width', 'lc-woo-integration' ),
				'id' => 'css_border_width',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.images',
				'affect_on_change_rule' => 'border-width',
				'section' => 'styling',
				'ext' => 'px',
			),
			array(
				'label' => __( 'Borders', 'lc-woo-integration' ),
				'id' => 'css_border_trbl',
				'std' => 'top right bottom left',
				'type' => 'checkbox',
				'choices' => array(
					array(
						'label' => __( 'Top', 'lc-woo-integration' ),
						'value' => 'top',
					),
					array(
						'label' => __( 'Right', 'lc-woo-integration' ),
						'value' => 'right',
					),
					array(
						'label' => __( 'Bottom', 'lc-woo-integration' ),
						'value' => 'bottom',
					),
					array(
						'label' => __( 'Left', 'lc-woo-integration' ),
						'value' => 'left',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => '.images',
				'affect_on_change_rule' => 'border-style',
				'section' => 'styling',
			),
			array(
				'label' => __( 'Border Radius', 'lc-woo-integration' ),
				'id' => 'css_border_radius',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.images',
				'affect_on_change_rule' => 'border-radius',
				'section' => 'styling',
				'ext' => 'px',
			),
			array(
				'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_margin_bottom',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.images',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'styling',
				'ext' => 'px',
			),
			array(
				'label' => __( 'Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_padding_vertical',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.images > img',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'styling',
				'ext' => 'px',
			),
			array(
				'label' => __( 'Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_padding_horizontal',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.images > img',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'styling',
				'ext' => 'px',
			),
			array(
				'label' => __( 'Width', 'live-composer-page-builder' ),
				'id' => 'css_width',
				'std' => '',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.images a.woocommerce-main-image img, .images > img',
				'affect_on_change_rule' => 'width',
				'section' => 'styling',
				'ext' => '%',
				'min' => 0,
				'max' => 100,
				'increment' => 1,
			),
			array(
				'label' => __( 'Height', 'live-composer-page-builder' ),
				'id' => 'css_height',
				'std' => '',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.images a.woocommerce-main-image img, .images > img',
				'affect_on_change_rule' => 'height',
				'section' => 'styling',
				'ext' => '%',
				'min' => 0,
				'max' => 100,
				'increment' => 1,
			),

			/**
			 * Thumbnails
			 */

			array(
				'label' => __( 'Number of columns', 'lc-woo-integration' ),
				'id' => 'thumbnail_columns',
				'std' => '3',
				'type' => 'select',
				'refresh_on_change' => true,
				'section' => 'styling',
				'tab' => __( 'Thumbnails', 'lc-woo-integration' ),
				'choices' => array(
					array(
						'label' => __( 'One', 'lc-woo-integration' ),
						'value' => '1',
					),
					array(
						'label' => __( 'Two', 'lc-woo-integration' ),
						'value' => '2',
					),
					array(
						'label' => __( 'Three', 'lc-woo-integration' ),
						'value' => '3',
					),
					array(
						'label' => __( 'Four', 'lc-woo-integration' ),
						'value' => '4',
					),
				),
			),

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_thumb_bg_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.images .thumbnails',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Thumbnails', 'lc-woo-integration' ),
			),

			array(
				'label' => __( 'Opacity', 'lc-woo-integration' ),
				'id' => 'css_thumbnails_opacity',
				'std' => '.5',
				'type' => 'slider',
				'ext' => '',
				'min' => 0,
				'max' => 1,
				'increment' => 0.01,
				'refresh_on_change' => false,
				'affect_on_change_el' => '.images .thumbnails a',
				'affect_on_change_rule' => 'opacity',
				'section' => 'styling',
				'tab' => __( 'Thumbnails', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Opacity – on hover', 'lc-woo-integration' ),
				'id' => 'css_thumbnails_opacity_hover',
				'std' => '1',
				'type' => 'slider',
				'ext' => '',
				'min' => 0,
				'max' => 1,
				'increment' => 0.01,
				'refresh_on_change' => false,
				'affect_on_change_el' => '.images .thumbnails a:hover',
				'affect_on_change_rule' => 'opacity',
				'section' => 'styling',
				'tab' => __( 'Thumbnails', 'lc-woo-integration' ),
			),

			array(
				'label' => __( 'Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_thumbnails_padding_vertical',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.images .thumbnails, .images .thumbnails a',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'styling',
				'tab' => __( 'Thumbnails', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_thumbnails_padding_horizontal',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.images .thumbnails, .images .thumbnails a',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'styling',
				'tab' => __( 'Thumbnails', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Width', 'live-composer-page-builder' ),
				'id' => 'css_thumbnails_width',
				'std' => '',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.images .thumbnails a img',
				'affect_on_change_rule' => 'width',
				'section' => 'styling',
				'tab' => __( 'Thumbnails', 'lc-woo-integration' ),
				'ext' => '%',
				'min' => 0,
				'max' => 100,
				'increment' => 1,
			),
			array(
				'label' => __( 'Height', 'live-composer-page-builder' ),
				'id' => 'css_thumbnails_height',
				'std' => '',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.images .thumbnails a img',
				'affect_on_change_rule' => 'height',
				'section' => 'styling',
				'tab' => __( 'Thumbnails', 'lc-woo-integration' ),
				'ext' => '%',
				'min' => 0,
				'max' => 100,
				'increment' => 1,
			),

			/**
			 * Responsive: Tablet
			 */

			array(
				'label' => __( 'Responsive', 'lc-woo-integration' ),
				'id' => 'css_res_t',
				'std' => 'disabled',
				'type' => 'select',
				'choices' => array(
					array(
						'label' => __( 'Disabled', 'lc-woo-integration' ),
						'value' => 'disabled',
					),
					array(
						'label' => __( 'Enabled', 'lc-woo-integration' ),
						'value' => 'enabled',
					),
				),
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_t_margin_bottom',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.images',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_t_padding_vertical',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.images',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_t_padding_horizontal',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.images',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Image - Width', 'live-composer-page-builder' ),
				'id' => 'css_res_t_image_width',
				'std' => '',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.images a.woocommerce-main-image img, .images > img',
				'affect_on_change_rule' => 'width',
				'section' => 'responsive',
				'ext' => '%',
				'min' => 0,
				'max' => 100,
				'increment' => 1,
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Image - Height', 'live-composer-page-builder' ),
				'id' => 'css_res_t_image_height',
				'std' => '',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.images a.woocommerce-main-image img, .images > img',
				'affect_on_change_rule' => 'height',
				'section' => 'responsive',
				'ext' => '%',
				'min' => 0,
				'max' => 100,
				'increment' => 1,
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Thumbnails - Width', 'live-composer-page-builder' ),
				'id' => 'css_res_t_thumbnails_width',
				'std' => '',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.images .thumbnails a img',
				'affect_on_change_rule' => 'width',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => '%',
				'min' => 0,
				'max' => 100,
				'increment' => 1,
			),
			array(
				'label' => __( 'Thumbnails - Height', 'live-composer-page-builder' ),
				'id' => 'css_res_t_thumbnails_height',
				'std' => '',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.images .thumbnails a img',
				'affect_on_change_rule' => 'height',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => '%',
				'min' => 0,
				'max' => 100,
				'increment' => 1,
			),

			/**
			 * Responsive Phone
			 */

			array(
				'label' => __( 'Responsive', 'lc-woo-integration' ),
				'id' => 'css_res_p',
				'std' => 'disabled',
				'type' => 'select',
				'choices' => array(
					array(
						'label' => __( 'Disabled', 'lc-woo-integration' ),
						'value' => 'disabled',
					),
					array(
						'label' => __( 'Enabled', 'lc-woo-integration' ),
						'value' => 'enabled',
					),
				),
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_p_margin_bottom',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.images',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_p_padding_vertical',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.images',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_p_padding_horizontal',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.images',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Image - Width', 'live-composer-page-builder' ),
				'id' => 'css_res_p_image_width',
				'std' => '',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.images a.woocommerce-main-image img, .images > img',
				'affect_on_change_rule' => 'width',
				'section' => 'responsive',
				'ext' => '%',
				'min' => 0,
				'max' => 100,
				'increment' => 1,
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Image - Height', 'live-composer-page-builder' ),
				'id' => 'css_res_p_image_height',
				'std' => '',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.images a.woocommerce-main-image img, .images > img',
				'affect_on_change_rule' => 'height',
				'section' => 'responsive',
				'ext' => '%',
				'min' => 0,
				'max' => 100,
				'increment' => 1,
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Thumbnails - Width', 'live-composer-page-builder' ),
				'id' => 'css_res_p_thumbnails_width',
				'std' => '',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.images .thumbnails a img',
				'affect_on_change_rule' => 'width',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'ext' => '%',
				'min' => 0,
				'max' => 100,
				'increment' => 1,
			),
			array(
				'label' => __( 'Thumbnails - Height', 'live-composer-page-builder' ),
				'id' => 'css_res_p_thumbnails_height',
				'std' => '',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.images .thumbnails a img',
				'affect_on_change_rule' => 'height',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'ext' => '%',
				'min' => 0,
				'max' => 100,
				'increment' => 1,
			),
		);

		$options = array_merge( $options, $this->shared_options( 'animation_options' ) );
		$options = array_merge( $options, $this->presets_options() );

		return apply_filters( 'dslc_module_options', $options, $this->module_id );
	}

	/**
	 * Module HTML output.
	 *
	 * @param  array $options Module options to fill the module template.
	 */
	function output( $options ) {

		$this->module_start( $options );

		global $dslc_active;

		if ( 'dslc_templates' === get_post_type() || $dslc_active ) {

			/**
			 * If current page is Product template editng
			 * If LC editing mode is active ($dslc_active) it means we edit the product template
			 * in this case some of the modules like Product Thumbnails can't work,
			 * so we print a placehoder HTML for better user experience while editing template
			 */

			$placeholder_img_src = wc_placeholder_img_src();
			echo '<div class="images">';

			// Product Image Placeholder.
			echo apply_filters( 'woocommerce_single_product_image_html', sprintf( '<img src="%s" alt="%s" />', $placeholder_img_src, __( 'Placeholder', 'woocommerce' ) ) );

			$columns = $options['thumbnail_columns'];

			// Save columns number into database as global value.
			set_theme_mod( 'wc_product_thumb_cols', $columns );

			// Product Thumbnails Placeholder.
			echo '<div class="thumbnails columns-' . $columns . '">';
				switch ( $columns ) {
					case 1:
						printf( '<a href="%s" class="zoom first last" title="services-mobile-marketing" data-rel="prettyPhoto[product-gallery]"><img width="180" height="180" src="%s" class="attachment-shop_thumbnail" alt=""></a>', $placeholder_img_src, $placeholder_img_src );
						printf( '<a href="%s" class="zoom first last" title="services-mobile-marketing" data-rel="prettyPhoto[product-gallery]"><img width="180" height="180" src="%s" class="attachment-shop_thumbnail" alt=""></a>', $placeholder_img_src, $placeholder_img_src );
						printf( '<a href="%s" class="zoom first last" title="services-mobile-marketing" data-rel="prettyPhoto[product-gallery]"><img width="180" height="180" src="%s" class="attachment-shop_thumbnail" alt=""></a>', $placeholder_img_src, $placeholder_img_src );
						printf( '<a href="%s" class="zoom first last" title="services-mobile-marketing" data-rel="prettyPhoto[product-gallery]"><img width="180" height="180" src="%s" class="attachment-shop_thumbnail" alt=""></a>', $placeholder_img_src, $placeholder_img_src );
						printf( '<a href="%s" class="zoom first last" title="services-mobile-marketing" data-rel="prettyPhoto[product-gallery]"><img width="180" height="180" src="%s" class="attachment-shop_thumbnail" alt=""></a>', $placeholder_img_src, $placeholder_img_src );
						printf( '<a href="%s" class="zoom first last" title="services-mobile-marketing" data-rel="prettyPhoto[product-gallery]"><img width="180" height="180" src="%s" class="attachment-shop_thumbnail" alt=""></a>', $placeholder_img_src, $placeholder_img_src );
						break;

					case 2:
						printf( '<a href="%s" class="zoom first" title="services-mobile-marketing" data-rel="prettyPhoto[product-gallery]"><img width="180" height="180" src="%s" class="attachment-shop_thumbnail" alt=""></a>', $placeholder_img_src, $placeholder_img_src );
						printf( '<a href="%s" class="zoom last" title="services-mobile-marketing" data-rel="prettyPhoto[product-gallery]"><img width="180" height="180" src="%s" class="attachment-shop_thumbnail" alt=""></a>', $placeholder_img_src, $placeholder_img_src );
						printf( '<a href="%s" class="zoom first" title="services-mobile-marketing" data-rel="prettyPhoto[product-gallery]"><img width="180" height="180" src="%s" class="attachment-shop_thumbnail" alt=""></a>', $placeholder_img_src, $placeholder_img_src );
						printf( '<a href="%s" class="zoom last" title="services-mobile-marketing" data-rel="prettyPhoto[product-gallery]"><img width="180" height="180" src="%s" class="attachment-shop_thumbnail" alt=""></a>', $placeholder_img_src, $placeholder_img_src );
						printf( '<a href="%s" class="zoom first" title="services-mobile-marketing" data-rel="prettyPhoto[product-gallery]"><img width="180" height="180" src="%s" class="attachment-shop_thumbnail" alt=""></a>', $placeholder_img_src, $placeholder_img_src );
						printf( '<a href="%s" class="zoom last" title="services-mobile-marketing" data-rel="prettyPhoto[product-gallery]"><img width="180" height="180" src="%s" class="attachment-shop_thumbnail" alt=""></a>', $placeholder_img_src, $placeholder_img_src );
						break;

					case 4:
						printf( '<a href="%s" class="zoom first" title="services-mobile-marketing" data-rel="prettyPhoto[product-gallery]"><img width="180" height="180" src="%s" class="attachment-shop_thumbnail" alt=""></a>', $placeholder_img_src, $placeholder_img_src );
						printf( '<a href="%s" class="zoom" title="services-mobile-marketing" data-rel="prettyPhoto[product-gallery]"><img width="180" height="180" src="%s" class="attachment-shop_thumbnail" alt=""></a>', $placeholder_img_src, $placeholder_img_src );
						printf( '<a href="%s" class="zoom" title="services-mobile-marketing" data-rel="prettyPhoto[product-gallery]"><img width="180" height="180" src="%s" class="attachment-shop_thumbnail" alt=""></a>', $placeholder_img_src, $placeholder_img_src );
						printf( '<a href="%s" class="zoom last" title="services-mobile-marketing" data-rel="prettyPhoto[product-gallery]"><img width="180" height="180" src="%s" class="attachment-shop_thumbnail" alt=""></a>', $placeholder_img_src, $placeholder_img_src );
						printf( '<a href="%s" class="zoom first" title="services-mobile-marketing" data-rel="prettyPhoto[product-gallery]"><img width="180" height="180" src="%s" class="attachment-shop_thumbnail" alt=""></a>', $placeholder_img_src, $placeholder_img_src );
						printf( '<a href="%s" class="zoom" title="services-mobile-marketing" data-rel="prettyPhoto[product-gallery]"><img width="180" height="180" src="%s" class="attachment-shop_thumbnail" alt=""></a>', $placeholder_img_src, $placeholder_img_src );
						break;

					case 5:
						printf( '<a href="%s" class="zoom first" title="services-mobile-marketing" data-rel="prettyPhoto[product-gallery]"><img width="180" height="180" src="%s" class="attachment-shop_thumbnail" alt=""></a>', $placeholder_img_src, $placeholder_img_src );
						printf( '<a href="%s" class="zoom" title="services-mobile-marketing" data-rel="prettyPhoto[product-gallery]"><img width="180" height="180" src="%s" class="attachment-shop_thumbnail" alt=""></a>', $placeholder_img_src, $placeholder_img_src );
						printf( '<a href="%s" class="zoom" title="services-mobile-marketing" data-rel="prettyPhoto[product-gallery]"><img width="180" height="180" src="%s" class="attachment-shop_thumbnail" alt=""></a>', $placeholder_img_src, $placeholder_img_src );
						printf( '<a href="%s" class="zoom" title="services-mobile-marketing" data-rel="prettyPhoto[product-gallery]"><img width="180" height="180" src="%s" class="attachment-shop_thumbnail" alt=""></a>', $placeholder_img_src, $placeholder_img_src );
						printf( '<a href="%s" class="zoom last" title="services-mobile-marketing" data-rel="prettyPhoto[product-gallery]"><img width="180" height="180" src="%s" class="attachment-shop_thumbnail" alt=""></a>', $placeholder_img_src, $placeholder_img_src );
						printf( '<a href="%s" class="zoom first" title="services-mobile-marketing" data-rel="prettyPhoto[product-gallery]"><img width="180" height="180" src="%s" class="attachment-shop_thumbnail" alt=""></a>', $placeholder_img_src, $placeholder_img_src );
						break;

					default:
						printf( '<a href="%s" class="zoom first" title="services-mobile-marketing" data-rel="prettyPhoto[product-gallery]"><img width="180" height="180" src="%s" class="attachment-shop_thumbnail" alt=""></a>', $placeholder_img_src, $placeholder_img_src );
						printf( '<a href="%s" class="zoom" title="services-mobile-marketing" data-rel="prettyPhoto[product-gallery]"><img width="180" height="180" src="%s" class="attachment-shop_thumbnail" alt=""></a>', $placeholder_img_src, $placeholder_img_src );
						printf( '<a href="%s" class="zoom last" title="services-mobile-marketing" data-rel="prettyPhoto[product-gallery]"><img width="180" height="180" src="%s" class="attachment-shop_thumbnail" alt=""></a>', $placeholder_img_src, $placeholder_img_src );
						printf( '<a href="%s" class="zoom first" title="services-mobile-marketing" data-rel="prettyPhoto[product-gallery]"><img width="180" height="180" src="%s" class="attachment-shop_thumbnail" alt=""></a>', $placeholder_img_src, $placeholder_img_src );
						printf( '<a href="%s" class="zoom" title="services-mobile-marketing" data-rel="prettyPhoto[product-gallery]"><img width="180" height="180" src="%s" class="attachment-shop_thumbnail" alt=""></a>', $placeholder_img_src, $placeholder_img_src );
						printf( '<a href="%s" class="zoom last" title="services-mobile-marketing" data-rel="prettyPhoto[product-gallery]"><img width="180" height="180" src="%s" class="attachment-shop_thumbnail" alt=""></a>', $placeholder_img_src, $placeholder_img_src );
						break;
				}
			echo '</div>';
			echo '</div>';

		} else {

			if ( is_product() ) {

				/**
				 * Front-end without LC in editing mode. Output the product image using standard WooCommerce function.
				 */
				woocommerce_show_product_images();

			} else {
				if ( current_user_can( 'manage_options' ) ) {
				?>
					<div class="dslc-notification dslc-red">
						<?php esc_html_e( 'This module is for WooCommerce product pages only.', 'lc-woo-integration' ); ?>
					</div>
				<?php
				}
			}
		}

		$this->module_end( $options );

	}
}

/**
 * Register Module
 */
add_action('dslc_hook_register_modules',
	create_function( '', 'return dslc_register_module( "LCWoo_Image" );' )
);
