<?php
/**
 * Module Mini Cart
 *
 * @package Live Composer - WooCommerce integration
 */

// Prevent direct access to the file.
if ( ! defined( 'ABSPATH' ) ) {
	header( 'HTTP/1.0 403 Forbidden' );
	exit;
}

/**
 * Module Class
 */
class LCWoo_Mini_Cart extends DSLC_Module {

	/**
	 * Unique module id
	 *
	 * @var string
	 */
	var $module_id;

	/**
	 * Module label to show in the page builder
	 *
	 * @var string
	 */
	var $module_title;

	/**
	 * Module icon name (FontAwesome)
	 *
	 * @var string
	 */
	var $module_icon;

	/**
	 * Section in the modules panel that includes this module
	 *
	 * @var string
	 */
	var $module_category;

	/**
	 * Exclude from main listing
	 *
	 * @var string
	 */
	var $exclude_from_main_listing;

	/**
	 * Construct
	 */
	function __construct() {

		$this->module_id = 'LCWoo_Mini_Cart';
		$this->module_title = __( 'Mini Cart', 'lc-woo-integration' );
		$this->module_icon = 'bitbucket';
		$this->module_category = 'Woo Product';
		$this->exclude_from_main_listing = true;
	}

	/**
	 * Options
	 */
	function options() {
		$options = array(

			array(
				'label' => __( 'Show On', 'lc-woo-integration' ),
				'id' => 'css_show_on',
				'std' => 'desktop tablet phone',
				'type' => 'checkbox',
				'choices' => array(
					array(
						'label' => __( 'Desktop', 'lc-woo-integration' ),
						'value' => 'desktop',
					),
					array(
						'label' => __( 'Tablet', 'lc-woo-integration' ),
						'value' => 'tablet',
					),
					array(
						'label' => __( 'Phone', 'lc-woo-integration' ),
						'value' => 'phone',
					),
				),
			),

			/**
			 * General
			 */

			array(
				'label' => __( 'Elements', 'lc-woo-integration' ),
				'id' => 'elements',
				'std' => 'price item icon',
				'type' => 'checkbox',
				'choices' => array(
					array(
						'label' => __( 'Price', 'lc-woo-integration' ),
						'value' => 'price',
					),
					array(
						'label' => __( 'Item', 'lc-woo-integration' ),
						'value' => 'item',
					),
					array(
						'label' => __( 'Icon', 'lc-woo-integration' ),
						'value' => 'icon',
					),
				),
				'section' => 'styling',
			),
			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_cart_list_bg_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
			),
			array(
				'label' => __( 'Border Color', 'lc-woo-integration' ),
				'id' => 'css_cart_list_border_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart',
				'affect_on_change_rule' => 'border-color',
				'section' => 'styling',
			),
			array(
				'label' => __( 'Border Width', 'lc-woo-integration' ),
				'id' => 'css_cart_list_border_width',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart',
				'affect_on_change_rule' => 'border-width',
				'section' => 'styling',
				'ext' => 'px',
			),
			array(
				'label' => __( 'Border Radius', 'lc-woo-integration' ),
				'id' => 'css_cart_list_border_radius',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart',
				'affect_on_change_rule' => 'border-radius',
				'section' => 'styling',
				'ext' => 'px',
			),
			array(
				'label' => __( 'Borders', 'lc-woo-integration' ),
				'id' => 'css_cart_list_border_trbl',
				'std' => 'top right bottom left',
				'type' => 'checkbox',
				'choices' => array(
					array(
						'label' => __( 'Top', 'lc-woo-integration' ),
						'value' => 'top',
					),
					array(
						'label' => __( 'Right', 'lc-woo-integration' ),
						'value' => 'right',
					),
					array(
						'label' => __( 'Bottom', 'lc-woo-integration' ),
						'value' => 'bottom',
					),
					array(
						'label' => __( 'Left', 'lc-woo-integration' ),
						'value' => 'left',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart',
				'affect_on_change_rule' => 'border-style',
				'section' => 'styling',
			),
			array(
				'label' => __( 'Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_cart_list_padding_vertical',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart a.cart-contents',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'styling',
				'ext' => 'px',
			),
			array(
				'label' => __( 'Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_cart_list_padding_horizontal',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart a.cart-contents',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'styling',
				'ext' => 'px',
			),

			/**
			 * Typography
			 */

			array(
				'label' => __( 'Price - Color', 'lc-woo-integration' ),
				'id' => 'css_typography_price_color',
				'std' => '#404040',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart a.cart-contents span.amount',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Typography', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Price - Font Size', 'lc-woo-integration' ),
				'id' => 'css_typography_price_font_size',
				'std' => '17',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart a.cart-contents span.amount',
				'affect_on_change_rule' => 'font-size',
				'section' => 'styling',
				'tab' => __( 'Typography', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Price - Font Weight', 'lc-woo-integration' ),
				'id' => 'css_typography_price_font_weight',
				'std' => '400',
				'type' => 'select',
				'choices' => array(
					array(
						'label' => '100 - Thin',
						'value' => '100',
					),
					array(
						'label' => '200 - Extra Light',
						'value' => '200',
					),
					array(
						'label' => '300 - Light',
						'value' => '300',
					),
					array(
						'label' => '400 - Normal',
						'value' => '400',
					),
					array(
						'label' => '500 - Medium',
						'value' => '500',
					),
					array(
						'label' => '600 - Semi Bold',
						'value' => '600',
					),
					array(
						'label' => '700 - Bold',
						'value' => '700',
					),
					array(
						'label' => '800 - Extra Bold',
						'value' => '800',
					),
					array(
						'label' => '900 - Black',
						'value' => '900',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart a.cart-contents span.amount',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'tab' => __( 'Typography', 'lc-woo-integration' ),
				'ext' => '',
			),
			array(
				'label' => __( 'Price - Line Height', 'lc-woo-integration' ),
				'id' => 'css_typography_price_line_height',
				'std' => '25',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart a.cart-contents span.amount',
				'affect_on_change_rule' => 'line-height',
				'section' => 'styling',
				'tab' => __( 'Typography', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Item - Color', 'lc-woo-integration' ),
				'id' => 'css_typography_item_color',
				'std' => '#60646C',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart a.cart-contents span.count',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Typography', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Item - Font Size', 'lc-woo-integration' ),
				'id' => 'css_typography_item_font_size',
				'std' => '16',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart a.cart-contents span.count',
				'affect_on_change_rule' => 'font-size',
				'section' => 'styling',
				'tab' => __( 'Typography', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Item - Font Weight', 'lc-woo-integration' ),
				'id' => 'css_typography_item_font_weight',
				'std' => '300',
				'type' => 'select',
				'choices' => array(
					array(
						'label' => '100 - Thin',
						'value' => '100',
					),
					array(
						'label' => '200 - Extra Light',
						'value' => '200',
					),
					array(
						'label' => '300 - Light',
						'value' => '300',
					),
					array(
						'label' => '400 - Normal',
						'value' => '400',
					),
					array(
						'label' => '500 - Medium',
						'value' => '500',
					),
					array(
						'label' => '600 - Semi Bold',
						'value' => '600',
					),
					array(
						'label' => '700 - Bold',
						'value' => '700',
					),
					array(
						'label' => '800 - Extra Bold',
						'value' => '800',
					),
					array(
						'label' => '900 - Black',
						'value' => '900',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart a.cart-contents span.count',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'tab' => __( 'Typography', 'lc-woo-integration' ),
				'ext' => '',
			),
			array(
				'label' => __( 'Item - Line Height', 'lc-woo-integration' ),
				'id' => 'css_typography_item_line_height',
				'std' => '25',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart a.cart-contents span.count',
				'affect_on_change_rule' => 'line-height',
				'section' => 'styling',
				'tab' => __( 'Typography', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Font Family', 'lc-woo-integration' ),
				'id' => 'css_typography_font_family',
				'std' => '',
				'type' => 'font',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart a.cart-contents',
				'affect_on_change_rule' => 'font-family',
				'section' => 'styling',
				'tab' => __( 'Typography', 'lc-woo-integration' ),
			),

			/**
			 * Icon
			 */

			array(
				'label' => __( 'Color', 'lc-woo-integration' ),
				'id' => 'css_icon_color',
				'std' => '#404040',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart a.cart-contents span.dslc-icon-shopping-cart',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Icon', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Size', 'lc-woo-integration' ),
				'id' => 'css_icon_font_size',
				'std' => '17',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart a.cart-contents span.dslc-icon-shopping-cart',
				'affect_on_change_rule' => 'font-size',
				'section' => 'styling',
				'tab' => __( 'Icon', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Position', 'lc-woo-integration' ),
				'id' => 'css_icon_pos',
				'std' => 'right',
				'type' => 'select',
				'choices' => array(
					array(
						'label' => __( 'Right', 'lc-woo-integration' ),
						'value' => 'right',
					),
					array(
						'label' => __( 'None', 'lc-woo-integration' ),
						'value' => 'none',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart a.cart-contents span.dslc-icon-shopping-cart',
				'affect_on_change_rule' => 'float',
				'section' => 'styling',
				'tab' => __( 'Icon', 'lc-woo-integration' ),
				'visibility' => 'hidden',
			),

			/**
			 * Items
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_items_bg_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart ul.cart_list li',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Items', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Color', 'lc-woo-integration' ),
				'id' => 'css_items_border_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart ul.cart_list li',
				'affect_on_change_rule' => 'border-color',
				'section' => 'styling',
				'tab' => __( 'Items', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Width', 'lc-woo-integration' ),
				'id' => 'css_items_border_width',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart ul.cart_list li',
				'affect_on_change_rule' => 'border-width',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Items', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Radius', 'lc-woo-integration' ),
				'id' => 'css_items_border_radius',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart ul.cart_list li',
				'affect_on_change_rule' => 'border-radius',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Items', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Borders', 'lc-woo-integration' ),
				'id' => 'css_items_border_trbl',
				'std' => 'top right bottom left',
				'type' => 'checkbox',
				'choices' => array(
					array(
						'label' => __( 'Top', 'lc-woo-integration' ),
						'value' => 'top',
					),
					array(
						'label' => __( 'Right', 'lc-woo-integration' ),
						'value' => 'right',
					),
					array(
						'label' => __( 'Bottom', 'lc-woo-integration' ),
						'value' => 'bottom',
					),
					array(
						'label' => __( 'Left', 'lc-woo-integration' ),
						'value' => 'left',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart ul.cart_list li',
				'affect_on_change_rule' => 'border-style',
				'section' => 'styling',
				'tab' => __( 'Items', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_items_padding_vertical',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart ul.cart_list li',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Items', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_items_padding_horizontal',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart ul.cart_list li',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Items', 'lc-woo-integration' ),
			),

			/**
			 * Item > Remove
			 */
// WooCommerce add style - !important
/*			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_item_remove_bg_color',
				'std' => '#E2401C',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart ul.cart_list li a.remove',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Item > Remove', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Color', 'lc-woo-integration' ),
				'id' => 'css_item_remove_color',
				'std' => '#ffffff',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart ul.cart_list li a.remove',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Item > Remove', 'lc-woo-integration' ),
			),*/

			/**
			 * Item > Title
			 */

			array(
				'label' => __( 'Color', 'lc-woo-integration' ),
				'id' => 'css_item_name_color',
				'std' => '#404040',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart ul.cart_list li a',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Item > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Size', 'lc-woo-integration' ),
				'id' => 'css_item_name_font_size',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart ul.cart_list li a',
				'affect_on_change_rule' => 'font-size',
				'section' => 'styling',
				'tab' => __( 'Item > Title', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Font Weight', 'lc-woo-integration' ),
				'id' => 'css_item_name_font_weight',
				'std' => '500',
				'type' => 'select',
				'choices' => array(
					array(
						'label' => '100 - Thin',
						'value' => '100',
					),
					array(
						'label' => '200 - Extra Light',
						'value' => '200',
					),
					array(
						'label' => '300 - Light',
						'value' => '300',
					),
					array(
						'label' => '400 - Normal',
						'value' => '400',
					),
					array(
						'label' => '500 - Medium',
						'value' => '500',
					),
					array(
						'label' => '600 - Semi Bold',
						'value' => '600',
					),
					array(
						'label' => '700 - Bold',
						'value' => '700',
					),
					array(
						'label' => '800 - Extra Bold',
						'value' => '800',
					),
					array(
						'label' => '900 - Black',
						'value' => '900',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart ul.cart_list li a',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'tab' => __( 'Item > Title', 'lc-woo-integration' ),
				'ext' => '',
			),
			array(
				'label' => __( 'Font Family', 'lc-woo-integration' ),
				'id' => 'css_item_name_font_family',
				'std' => '',
				'type' => 'font',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart ul.cart_list li a',
				'affect_on_change_rule' => 'font-family',
				'section' => 'styling',
				'tab' => __( 'Item > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Line Height', 'lc-woo-integration' ),
				'id' => 'css_item_name_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart ul.cart_list li a',
				'affect_on_change_rule' => 'line-height',
				'section' => 'styling',
				'tab' => __( 'Item > Title', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_item_name_padding_horizontal',
				'std' => '5',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart ul.cart_list li a',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Item > Title', 'lc-woo-integration' ),
			),

			/**
			 * Item > Variation
			 */

			array(
				'label' => __( 'One - Color', 'lc-woo-integration' ),
				'id' => 'css_item_variation_dt_color',
				'std' => '#60646C',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart dt.variation-color',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Item > Variation', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Two - Color', 'lc-woo-integration' ),
				'id' => 'css_item_variation_dd_color',
				'std' => '#60646C',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart dd.variation-color',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Item > Variation', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Size', 'lc-woo-integration' ),
				'id' => 'css_item_variation_dt_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart dt.variation-color, .woo_mini_cart dd.variation-color',
				'affect_on_change_rule' => 'font-size',
				'section' => 'styling',
				'tab' => __( 'Item > Variation', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'One - Font Weight', 'lc-woo-integration' ),
				'id' => 'css_item_variation_dd_font_weight',
				'std' => '300',
				'type' => 'select',
				'choices' => array(
					array(
						'label' => '100 - Thin',
						'value' => '100',
					),
					array(
						'label' => '200 - Extra Light',
						'value' => '200',
					),
					array(
						'label' => '300 - Light',
						'value' => '300',
					),
					array(
						'label' => '400 - Normal',
						'value' => '400',
					),
					array(
						'label' => '500 - Medium',
						'value' => '500',
					),
					array(
						'label' => '600 - Semi Bold',
						'value' => '600',
					),
					array(
						'label' => '700 - Bold',
						'value' => '700',
					),
					array(
						'label' => '800 - Extra Bold',
						'value' => '800',
					),
					array(
						'label' => '900 - Black',
						'value' => '900',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart dd.variation-color',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'tab' => __( 'Item > Variation', 'lc-woo-integration' ),
				'ext' => '',
			),
			array(
				'label' => __( 'Two - Font Weight', 'lc-woo-integration' ),
				'id' => 'css_item_variation_font_weight',
				'std' => '500',
				'type' => 'select',
				'choices' => array(
					array(
						'label' => '100 - Thin',
						'value' => '100',
					),
					array(
						'label' => '200 - Extra Light',
						'value' => '200',
					),
					array(
						'label' => '300 - Light',
						'value' => '300',
					),
					array(
						'label' => '400 - Normal',
						'value' => '400',
					),
					array(
						'label' => '500 - Medium',
						'value' => '500',
					),
					array(
						'label' => '600 - Semi Bold',
						'value' => '600',
					),
					array(
						'label' => '700 - Bold',
						'value' => '700',
					),
					array(
						'label' => '800 - Extra Bold',
						'value' => '800',
					),
					array(
						'label' => '900 - Black',
						'value' => '900',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart dt.variation-color',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'tab' => __( 'Item > Variation', 'lc-woo-integration' ),
				'ext' => '',
			),
			array(
				'label' => __( 'Font Family', 'lc-woo-integration' ),
				'id' => 'css_item_variation_font_family',
				'std' => '',
				'type' => 'font',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart dt.variation-color, .woo_mini_cart dd.variation-color',
				'affect_on_change_rule' => 'font-family',
				'section' => 'styling',
				'tab' => __( 'Item > Variation', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Line Height', 'lc-woo-integration' ),
				'id' => 'css_item_variation_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart dt.variation-color, .woo_mini_cart dd.variation-color',
				'affect_on_change_rule' => 'line-height',
				'section' => 'styling',
				'tab' => __( 'Item > Variation', 'lc-woo-integration' ),
				'ext' => 'px',
			),

			/**
			 * Item > Quantity
			 */

			array(
				'label' => __( 'Color', 'lc-woo-integration' ),
				'id' => 'css_item_quantity_color',
				'std' => '#7f7f7f',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart ul.cart_list li span',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Item > Quantity', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Size', 'lc-woo-integration' ),
				'id' => 'css_item_quantity_font_size',
				'std' => '13',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart ul.cart_list li span',
				'affect_on_change_rule' => 'font-size',
				'section' => 'styling',
				'tab' => __( 'Item > Quantity', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Font Weight', 'lc-woo-integration' ),
				'id' => 'css_item_quantity_font_weight',
				'std' => '300',
				'type' => 'select',
				'choices' => array(
					array(
						'label' => '100 - Thin',
						'value' => '100',
					),
					array(
						'label' => '200 - Extra Light',
						'value' => '200',
					),
					array(
						'label' => '300 - Light',
						'value' => '300',
					),
					array(
						'label' => '400 - Normal',
						'value' => '400',
					),
					array(
						'label' => '500 - Medium',
						'value' => '500',
					),
					array(
						'label' => '600 - Semi Bold',
						'value' => '600',
					),
					array(
						'label' => '700 - Bold',
						'value' => '700',
					),
					array(
						'label' => '800 - Extra Bold',
						'value' => '800',
					),
					array(
						'label' => '900 - Black',
						'value' => '900',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart ul.cart_list li span',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'tab' => __( 'Item > Quantity', 'lc-woo-integration' ),
				'ext' => '',
			),
			array(
				'label' => __( 'Font Family', 'lc-woo-integration' ),
				'id' => 'css_item_quantity_font_family',
				'std' => '',
				'type' => 'font',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart ul.cart_list li span',
				'affect_on_change_rule' => 'font-family',
				'section' => 'styling',
				'tab' => __( 'Item > Quantity', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Line Height', 'lc-woo-integration' ),
				'id' => 'css_item_quantity_line_height',
				'std' => '20',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart ul.cart_list li span',
				'affect_on_change_rule' => 'line-height',
				'section' => 'styling',
				'tab' => __( 'Item > Quantity', 'lc-woo-integration' ),
				'ext' => 'px',
			),

			/**
			 * Total
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_total_bg_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart p.total',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Total', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Color', 'lc-woo-integration' ),
				'id' => 'css_total_border_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart p.total',
				'affect_on_change_rule' => 'border-color',
				'section' => 'styling',
				'tab' => __( 'Total', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Width', 'lc-woo-integration' ),
				'id' => 'css_total_border_width',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart p.total',
				'affect_on_change_rule' => 'border-width',
				'section' => 'styling',
				'tab' => __( 'Total', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Border Radius', 'lc-woo-integration' ),
				'id' => 'css_total_border_radius',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart p.total',
				'affect_on_change_rule' => 'border-radius',
				'section' => 'styling',
				'tab' => __( 'Total', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Borders', 'lc-woo-integration' ),
				'id' => 'css_total_border_trbl',
				'std' => 'top right bottom left',
				'type' => 'checkbox',
				'choices' => array(
					array(
						'label' => __( 'Top', 'lc-woo-integration' ),
						'value' => 'top',
					),
					array(
						'label' => __( 'Right', 'lc-woo-integration' ),
						'value' => 'right',
					),
					array(
						'label' => __( 'Bottom', 'lc-woo-integration' ),
						'value' => 'bottom',
					),
					array(
						'label' => __( 'Left', 'lc-woo-integration' ),
						'value' => 'left',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart p.total',
				'affect_on_change_rule' => 'border-style',
				'section' => 'styling',
				'tab' => __( 'Total', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Title - Color', 'lc-woo-integration' ),
				'id' => 'css_total_title_color',
				'std' => '#60646C',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart p.total strong',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Total', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Title - Font Size', 'lc-woo-integration' ),
				'id' => 'css_total_title_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart p.total strong',
				'affect_on_change_rule' => 'font-size',
				'section' => 'styling',
				'tab' => __( 'Total', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Title - Font Weight', 'lc-woo-integration' ),
				'id' => 'css_total_title_font_weight',
				'std' => '500',
				'type' => 'select',
				'choices' => array(
					array(
						'label' => '100 - Thin',
						'value' => '100',
					),
					array(
						'label' => '200 - Extra Light',
						'value' => '200',
					),
					array(
						'label' => '300 - Light',
						'value' => '300',
					),
					array(
						'label' => '400 - Normal',
						'value' => '400',
					),
					array(
						'label' => '500 - Medium',
						'value' => '500',
					),
					array(
						'label' => '600 - Semi Bold',
						'value' => '600',
					),
					array(
						'label' => '700 - Bold',
						'value' => '700',
					),
					array(
						'label' => '800 - Extra Bold',
						'value' => '800',
					),
					array(
						'label' => '900 - Black',
						'value' => '900',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart p.total strong',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'tab' => __( 'Total', 'lc-woo-integration' ),
				'ext' => '',
			),
			array(
				'label' => __( 'Title - Line Height', 'lc-woo-integration' ),
				'id' => 'css_total_title_line_height',
				'std' => '25',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart p.total strong',
				'affect_on_change_rule' => 'line-height',
				'section' => 'styling',
				'tab' => __( 'Total', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Price - Color', 'lc-woo-integration' ),
				'id' => 'css_total_price_color',
				'std' => '#7f7f7f',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart p.total span',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Total', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Price - Font Size', 'lc-woo-integration' ),
				'id' => 'css_total_price_font_size',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart p.total span',
				'affect_on_change_rule' => 'font-size',
				'section' => 'styling',
				'tab' => __( 'Total', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Price - Font Weight', 'lc-woo-integration' ),
				'id' => 'css_total_price_font_weight',
				'std' => '300',
				'type' => 'select',
				'choices' => array(
					array(
						'label' => '100 - Thin',
						'value' => '100',
					),
					array(
						'label' => '200 - Extra Light',
						'value' => '200',
					),
					array(
						'label' => '300 - Light',
						'value' => '300',
					),
					array(
						'label' => '400 - Normal',
						'value' => '400',
					),
					array(
						'label' => '500 - Medium',
						'value' => '500',
					),
					array(
						'label' => '600 - Semi Bold',
						'value' => '600',
					),
					array(
						'label' => '700 - Bold',
						'value' => '700',
					),
					array(
						'label' => '800 - Extra Bold',
						'value' => '800',
					),
					array(
						'label' => '900 - Black',
						'value' => '900',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart p.total span',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'tab' => __( 'Total', 'lc-woo-integration' ),
				'ext' => '',
			),
			array(
				'label' => __( 'Price - Line Height', 'lc-woo-integration' ),
				'id' => 'css_total_price_line_height',
				'std' => '25',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart p.total span',
				'affect_on_change_rule' => 'line-height',
				'section' => 'styling',
				'tab' => __( 'Total', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Font Family', 'lc-woo-integration' ),
				'id' => 'css_total_font_family',
				'std' => '',
				'type' => 'font',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart p.total',
				'affect_on_change_rule' => 'font-family',
				'section' => 'styling',
				'tab' => __( 'Total', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Text Align', 'lc-woo-integration' ),
				'id' => 'css_total_text_align',
				'std' => 'center',
				'type' => 'text_align',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart p.total',
				'affect_on_change_rule' => 'text-align',
				'section' => 'styling',
				'tab' => __( 'Total', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_total_padding_vertical',
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart p.total',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Total', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_total_padding_horizontal',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart p.total',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Total', 'lc-woo-integration' ),
			),

			/**
			 * Button
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_button_bg_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart p.buttons',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Color', 'lc-woo-integration' ),
				'id' => 'css_button_border_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart p.buttons',
				'affect_on_change_rule' => 'border-color',
				'section' => 'styling',
				'tab' => __( 'Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Width', 'lc-woo-integration' ),
				'id' => 'css_button_border_width',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart p.buttons',
				'affect_on_change_rule' => 'border-width',
				'section' => 'styling',
				'tab' => __( 'Button', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Border Radius', 'lc-woo-integration' ),
				'id' => 'css_button_border_radius',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart p.buttons',
				'affect_on_change_rule' => 'border-radius',
				'section' => 'styling',
				'tab' => __( 'Button', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Borders', 'lc-woo-integration' ),
				'id' => 'css_button_border_trbl',
				'std' => 'top right bottom left',
				'type' => 'checkbox',
				'choices' => array(
					array(
						'label' => __( 'Top', 'lc-woo-integration' ),
						'value' => 'top',
					),
					array(
						'label' => __( 'Right', 'lc-woo-integration' ),
						'value' => 'right',
					),
					array(
						'label' => __( 'Bottom', 'lc-woo-integration' ),
						'value' => 'bottom',
					),
					array(
						'label' => __( 'Left', 'lc-woo-integration' ),
						'value' => 'left',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart p.buttons',
				'affect_on_change_rule' => 'border-style',
				'section' => 'styling',
				'tab' => __( 'Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Text Align', 'lc-woo-integration' ),
				'id' => 'css_button_text_align',
				'std' => 'center',
				'type' => 'text_align',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart p.buttons',
				'affect_on_change_rule' => 'text-align',
				'section' => 'styling',
				'tab' => __( 'Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_button_padding_vertical',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart p.buttons',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_button_padding_horizontal',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart p.buttons',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Color', 'lc-woo-integration' ),
				'id' => 'css_button_color',
				'std' => '#ffffff',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart p.buttons a',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Size', 'lc-woo-integration' ),
				'id' => 'css_button_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart p.buttons a',
				'affect_on_change_rule' => 'font-size',
				'section' => 'styling',
				'tab' => __( 'Button', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Font Family', 'lc-woo-integration' ),
				'id' => 'css_button_font_family',
				'std' => '',
				'type' => 'font',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart p.buttons a',
				'affect_on_change_rule' => 'font-family',
				'section' => 'styling',
				'tab' => __( 'Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Weight', 'lc-woo-integration' ),
				'id' => 'css_button_font_weight',
				'std' => '400',
				'type' => 'select',
				'choices' => array(
					array(
						'label' => '100 - Thin',
						'value' => '100',
					),
					array(
						'label' => '200 - Extra Light',
						'value' => '200',
					),
					array(
						'label' => '300 - Light',
						'value' => '300',
					),
					array(
						'label' => '400 - Normal',
						'value' => '400',
					),
					array(
						'label' => '500 - Medium',
						'value' => '500',
					),
					array(
						'label' => '600 - Semi Bold',
						'value' => '600',
					),
					array(
						'label' => '700 - Bold',
						'value' => '700',
					),
					array(
						'label' => '800 - Extra Bold',
						'value' => '800',
					),
					array(
						'label' => '900 - Black',
						'value' => '900',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart p.buttons a',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'tab' => __( 'Button', 'lc-woo-integration' ),
				'ext' => '',
			),
			array(
				'label' => __( 'Line Height', 'lc-woo-integration' ),
				'id' => 'css_button_line_height',
				'std' => '25',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart p.buttons a',
				'affect_on_change_rule' => 'line-height',
				'section' => 'styling',
				'tab' => __( 'Button', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Button - BG Color', 'lc-woo-integration' ),
				'id' => 'css_button_sub_bg_color',
				'std' => '#EF510E',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart p.buttons a',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Button:hover - BG Color', 'lc-woo-integration' ),
				'id' => 'css_button_hover_sub_bg_color',
				'std' => '#000000',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart p.buttons a:hover',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Button - Border Color', 'lc-woo-integration' ),
				'id' => 'css_button_sub_border_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart p.buttons a',
				'affect_on_change_rule' => 'border-color',
				'section' => 'styling',
				'tab' => __( 'Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Button - Border Width', 'lc-woo-integration' ),
				'id' => 'css_button_sub_border_width',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart p.buttons a',
				'affect_on_change_rule' => 'border-width',
				'section' => 'styling',
				'tab' => __( 'Button', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Button - Border Radius', 'lc-woo-integration' ),
				'id' => 'css_button_sub_border_radius',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart p.buttons a',
				'affect_on_change_rule' => 'border-radius',
				'section' => 'styling',
				'tab' => __( 'Button', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Button - Borders', 'lc-woo-integration' ),
				'id' => 'css_button_sub_border_trbl',
				'std' => 'top right bottom left',
				'type' => 'checkbox',
				'choices' => array(
					array(
						'label' => __( 'Top', 'lc-woo-integration' ),
						'value' => 'top',
					),
					array(
						'label' => __( 'Right', 'lc-woo-integration' ),
						'value' => 'right',
					),
					array(
						'label' => __( 'Bottom', 'lc-woo-integration' ),
						'value' => 'bottom',
					),
					array(
						'label' => __( 'Left', 'lc-woo-integration' ),
						'value' => 'left',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart p.buttons a',
				'affect_on_change_rule' => 'border-style',
				'section' => 'styling',
				'tab' => __( 'Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Button - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_button_sub_padding_vertical',
				'std' => '7',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart p.buttons a',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Button - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_button_sub_padding_horizontal',
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart p.buttons a',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Button - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_button_sub_margin_bottom',
				'std' => '5',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart p.buttons a',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Button', 'lc-woo-integration' ),
			),

			/**
			 * Responsive Tablet
			 */

			array(
				'label' => __( 'Responsive', 'lc-woo-integration' ),
				'id' => 'css_res_t',
				'std' => 'disabled',
				'type' => 'select',
				'choices' => array(
					array(
						'label' => __( 'Disabled', 'lc-woo-integration' ),
						'value' => 'disabled',
					),
					array(
						'label' => __( 'Enabled', 'lc-woo-integration' ),
						'value' => 'enabled',
					),
				),
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Elements', 'lc-woo-integration' ),
				'id' => 'css_res_t_elements',
				'std' => 'price item icon',
				'type' => 'checkbox',
				'choices' => array(
					array(
						'label' => __( 'Price', 'lc-woo-integration' ),
						'value' => 'price',
					),
					array(
						'label' => __( 'Item', 'lc-woo-integration' ),
						'value' => 'item',
					),
					array(
						'label' => __( 'Icon', 'lc-woo-integration' ),
						'value' => 'icon',
					),
				),
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_t_cart_list_padding_vertical',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart a.cart-contents',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_t_cart_list_padding_horizontal',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart a.cart-contents',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Price - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_typography_price_font_size',
				'std' => '17',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart a.cart-contents span.amount',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Price - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_typography_price_line_height',
				'std' => '25',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart a.cart-contents span.amount',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Price - Margin Right', 'lc-woo-integration' ),
				'id' => 'css_res_t_typography_price_margin_right',
				'std' => '5',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart a.cart-contents span.amount',
				'affect_on_change_rule' => 'margin-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Item - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_typography_item_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart a.cart-contents span.count',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Item - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_typography_item_line_height',
				'std' => '25',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart a.cart-contents span.count',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Icon - Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_typography_icon_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart a.cart-contents span.dslc-icon-shopping-cart',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Icon - Position', 'lc-woo-integration' ),
				'id' => 'css_res_t_icon_pos',
				'std' => 'right',
				'type' => 'select',
				'choices' => array(
					array(
						'label' => __( 'Right', 'lc-woo-integration' ),
						'value' => 'right',
					),
					array(
						'label' => __( 'None', 'lc-woo-integration' ),
						'value' => 'none',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart a.cart-contents span.dslc-icon-shopping-cart',
				'affect_on_change_rule' => 'float',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'visibility' => 'hidden',
			),
			array(
				'label' => __( 'Items - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_t_items_padding_vertical',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart ul.cart_list li',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Items - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_t_items_padding_horizontal',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart ul.cart_list li',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Item > Title - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_item_name_font_size',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart ul.cart_list li a',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Item > Title - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_item_name_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart ul.cart_list li a',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Item > Title - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_t_item_name_padding_horizontal',
				'std' => '5',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart ul.cart_list li a',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Item > Variation - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_item_variation_dt_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart dt.variation-color, .woo_mini_cart dd.variation-color',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Item > Variation - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_item_variation_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart dt.variation-color, .woo_mini_cart dd.variation-color',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Item > Quantity - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_item_quantity_font_size',
				'std' => '13',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart ul.cart_list li span',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Item > Quantity - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_item_quantity_line_height',
				'std' => '20',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart ul.cart_list li span',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Title - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_total_title_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart p.total strong',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Title - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_total_title_line_height',
				'std' => '25',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart p.total strong',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Price - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_total_price_font_size',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart p.total span',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Price - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_total_price_line_height',
				'std' => '25',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart p.total span',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Total - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_t_total_padding_vertical',
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart p.total',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Total - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_t_total_padding_horizontal',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart p.total',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Button - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_button_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart p.buttons a',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Button - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_button_line_height',
				'std' => '25',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart p.buttons a',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Button - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_t_button_sub_padding_vertical',
				'std' => '7',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart p.buttons a',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Button - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_t_button_sub_padding_horizontal',
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart p.buttons a',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Button - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_t_button_sub_margin_bottom',
				'std' => '5',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart p.buttons a',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),

			/**
			 * Responsive Phone
			 */

			array(
				'label' => __( 'Responsive', 'lc-woo-integration' ),
				'id' => 'css_res_p',
				'std' => 'disabled',
				'type' => 'select',
				'choices' => array(
					array(
						'label' => __( 'Disabled', 'lc-woo-integration' ),
						'value' => 'disabled',
					),
					array(
						'label' => __( 'Enabled', 'lc-woo-integration' ),
						'value' => 'enabled',
					),
				),
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Elements', 'lc-woo-integration' ),
				'id' => 'css_res_p_elements',
				'std' => 'price item icon',
				'type' => 'checkbox',
				'choices' => array(
					array(
						'label' => __( 'Price', 'lc-woo-integration' ),
						'value' => 'price',
					),
					array(
						'label' => __( 'Item', 'lc-woo-integration' ),
						'value' => 'item',
					),
					array(
						'label' => __( 'Icon', 'lc-woo-integration' ),
						'value' => 'icon',
					),
				),
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_p_cart_list_padding_vertical',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart a.cart-contents',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_p_cart_list_padding_horizontal',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart a.cart-contents',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Price - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_typography_price_font_size',
				'std' => '17',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart a.cart-contents span.amount',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Price - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_typography_price_line_height',
				'std' => '25',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart a.cart-contents span.amount',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Price - Margin Right', 'lc-woo-integration' ),
				'id' => 'css_res_p_typography_price_margin_right',
				'std' => '5',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart a.cart-contents span.amount',
				'affect_on_change_rule' => 'margin-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Item - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_typography_item_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart a.cart-contents span.count',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Item - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_typography_item_line_height',
				'std' => '25',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart a.cart-contents span.count',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Icon - Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_typography_icon_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart a.cart-contents span.dslc-icon-shopping-cart',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Icon - Position', 'lc-woo-integration' ),
				'id' => 'css_res_p_icon_pos',
				'std' => 'right',
				'type' => 'select',
				'choices' => array(
					array(
						'label' => __( 'Right', 'lc-woo-integration' ),
						'value' => 'right',
					),
					array(
						'label' => __( 'None', 'lc-woo-integration' ),
						'value' => 'none',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_mini_cart a.cart-contents span.dslc-icon-shopping-cart',
				'affect_on_change_rule' => 'float',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'visibility' => 'hidden',
			),

		);

		$options = array_merge( $options, $this->shared_options( 'animation_options' ) );
		$options = array_merge( $options, $this->presets_options() );

		return apply_filters( 'dslc_module_options', $options, $this->module_id );
	}

	/**
	 * Module HTML output.
	 *
	 * @param  array $options Module options to fill the module template.
	 */
	function output( $options ) {

		$this->module_start( $options ); ?>

		<?php

		// Desktop.
		$elements = $options['elements'];
		if ( ! empty( $elements ) ) {
			$elements = explode( ' ', trim( $elements ) );
		} else {
			$elements = array();
		}

		// Tablet.
		$t_elements = $options['css_res_t_elements'];
		if ( ! empty( $t_elements ) ) {
			$t_elements = explode( ' ', trim( $t_elements ) );
		} else {
			$t_elements = array();
		}

		// Phone.
		$p_elements = $options['css_res_p_elements'];
		if ( ! empty( $p_elements ) ) {
			$p_elements = explode( ' ', trim( $p_elements ) );
		} else {
			$p_elements = array();
		}

		?>

		<div class='woo_mini_cart'>
			<a class="cart-contents" href="<?php echo WC()->cart->get_cart_url(); ?>" title="<?php esc_html_e( 'View your shopping cart', 'lc-woo-integration' ); ?>">
				<?php echo WC()->cart->get_cart_total(); ?>
				<span class="count"><?php echo sprintf ( _n( '%d item', '%d items', WC()->cart->cart_contents_count ), WC()->cart->cart_contents_count ); ?></span>
				<span class="dslc-icon dslc-icon-shopping-cart"></span>

				<style type="text/css">
					<?php // Desktop. ?>
					<?php
					if ( ! in_array( 'price', $elements ) ) {
						echo '.dslc-res-big .woo_mini_cart .amount, .dslc-res-smaller-monitor .woo_mini_cart .amount';
						echo '{ display: none; }';
					}
					?>
					<?php
					if ( ! in_array( 'item', $elements ) ) {
						echo '.dslc-res-big .woo_mini_cart .count, .dslc-res-smaller-monitor .woo_mini_cart .count';
						echo '{ display: none; }';
					}
					?>
					<?php
					if ( ! in_array( 'icon', $elements ) ) {
						echo '.dslc-res-big .woo_mini_cart .dslc-icon-shopping-cart, .dslc-res-smaller-monitor .woo_mini_cart .dslc-icon-shopping-cart';
						echo '{ display: none; }';
					}
					?>

					<?php // Tablet. ?>
					<?php
					if ( ! in_array( 'price', $t_elements ) ) {
						echo '.dslc-res-tablet .woo_mini_cart .amount';
						echo '{ display: none; }';
					}
					?>
					<?php
					if ( ! in_array( 'item', $t_elements ) ) {
						echo '.dslc-res-tablet .woo_mini_cart .count';
						echo '{ display: none; }';
					}
					?>
					<?php
					if ( ! in_array( 'icon', $t_elements ) ) {
						echo '.dslc-res-tablet .woo_mini_cart .dslc-icon-shopping-cart';
						echo '{ display: none; }';
					}
					?>

					<?php // Phone. ?>
					<?php
					if ( ! in_array( 'price', $p_elements ) ) {
						echo '.dslc-res-phone .woo_mini_cart .amount';
						echo '{ display: none; }';
					}
					?>
					<?php
					if ( ! in_array( 'item', $p_elements ) ) {
						echo '.dslc-res-phone .woo_mini_cart .count';
						echo '{ display: none; }';
					}
					?>
					<?php
					if ( ! in_array( 'icon', $p_elements ) ) {
						echo '.dslc-res-phone .woo_mini_cart .dslc-icon-shopping-cart';
						echo '{ display: none; }';
					}
					?>
				</style>
			</a>
			<div class='woo_shop_cart'>
				<?php woocommerce_mini_cart(); ?>
			</div>
		</div>

		<?php $this->module_end( $options );
	}
}

/**
 * Register Module
 */
add_action('dslc_hook_register_modules',
	create_function( '', 'return dslc_register_module( "LCWoo_Mini_Cart" );' )
);

/**
 * Header Add Cart.
 *
 * @param  array $fragments Module fragments to fill the module template.
 */
function woocommerce_header_add_to_cart_fragment( $fragments ) {
	ob_start();
	?>
	<a class="cart-contents" href="<?php echo WC()->cart->get_cart_url(); ?>" title="<?php esc_html_e( 'View your shopping cart', 'lc-woo-integration' ); ?>">
		<?php echo WC()->cart->get_cart_total(); ?>
		<span class="count"><?php echo sprintf ( _n( '%d item', '%d items', WC()->cart->cart_contents_count ), WC()->cart->cart_contents_count );  ?></span>
		<span class="dslc-icon dslc-icon-shopping-cart"></span>
	</a>

	<?php

	$fragments['a.cart-contents'] = ob_get_clean();

	return $fragments;
}
add_filter( 'woocommerce_add_to_cart_fragments', 'woocommerce_header_add_to_cart_fragment' );

/**
 * Header Add Cart addition
 *
 * @param  array $fragments Module fragments to fill the module template.
 */
function woocommerce_header_add_to_cart_fragment_addition( $fragments ) {
	ob_start();
	?>
	<div class='woo_shop_cart'>
		<?php woocommerce_mini_cart(); ?>
	</div>

	<?php

	$fragments['.woo_shop_cart'] = ob_get_clean();

	return $fragments;
}
add_filter( 'woocommerce_add_to_cart_fragments', 'woocommerce_header_add_to_cart_fragment_addition' );
