<?php
/**
 * Add, Edit, Save templates category.
 *
 * @package Live Composer - WooCommerce integration
 */

// Prevent direct access to the file.
if ( ! defined( 'ABSPATH' ) ) {
	header( 'HTTP/1.0 403 Forbidden' );
	exit;
}

/**
 * ----------------------------------------------------------------------
 * Add templates category and tag in the Live Composer
 * Products -> Categories and Products -> Tags
 */
function lcwoo_add_category_and_tag() {
?>
	<div class="form-field">
		<label for="lc_template"><?php esc_html_e( 'LC Template', 'woocommerce' ); ?></label>
		<select id="lc_template" name="lc_template" class="postform">
			<?php

			$type = 'dslc_templates';
			$args = array(
				'post_type' => $type,
				'post_status' => 'publish',
				'posts_per_page' => -1,
				'ignore_sticky_posts' => 1,
				'meta_query' => array(
			  		array(
			  			'key' => 'dslc_template_for',
			  			'value' => 'product_archive',
			  		),
			  	),
				'orderby' => 'meta_value',
				'meta_key' => 'dslc_template_type',
				'order' => 'ASC',
			);
			$my_query = null;
			$my_query = new WP_Query( $args );

			if ( $my_query->have_posts() ) {
				while ( $my_query->have_posts() ) : $my_query->the_post();

					$template_type = get_post_meta( get_the_ID(), 'dslc_template_type', true );

					if ( 'default' === $template_type ) { ?>
						<option value="">Default - <?php the_title(); ?></option>
					<?php
					} else { ?>
						<option value="<?php the_ID(); ?>"><?php the_title(); ?></option>
					<?php
					}

				endwhile;
			}

			wp_reset_query();
			?>
		</select>
	</div>
<?php
}
add_action( 'product_cat_add_form_fields', 'lcwoo_add_category_and_tag', 10, 2 );
add_action( 'product_tag_add_form_fields', 'lcwoo_add_category_and_tag', 10, 2 );

/**
 * ----------------------------------------------------------------------
 * Edit templates category and tag in the Live Composer
 * Products -> Categories and Products -> Tags
 *
 * @param string $term Get current term.
 */
function lcwoo_edit_category_and_tag( $term ) {

	$category_id = $term->term_id;
	$template_id = get_woocommerce_term_meta( $category_id, 'lc_template', $single = true );
	?>
	<tr class="form-field">
	<th scope="row" valign="top"><label for="lc_template"><?php esc_html_e( 'LC Template', 'woocommerce' ); ?></th>
		<td>
			<select id="lc_template" name="lc_template" class="postform">
				<?php

				$type = 'dslc_templates';
				$args = array(
					'post_type' => $type,
					'post_status' => 'publish',
					'posts_per_page' => -1,
					'ignore_sticky_posts' => 1,
					'meta_query' => array(
				  		array(
				  			'key' => 'dslc_template_for',
				  			'value' => 'product_archive',
				  		),
				  	),
					'orderby' => 'meta_value',
					'meta_key' => 'dslc_template_type',
					'order' => 'ASC',
				);
				$my_query = null;
				$my_query = new WP_Query( $args );

				if ( $my_query->have_posts() ) {
					while ( $my_query->have_posts() ) : $my_query->the_post();

						$template_type = get_post_meta( get_the_ID(), 'dslc_template_type', true );

						if ( 'default' === $template_type ) { ?>
							<option value="">Default - <?php the_title(); ?></option>
						<?php
						} else { ?>
							<option value="<?php the_ID(); ?>" <?php selected( get_the_ID(), $template_id ); ?>><?php the_title(); ?></option>
						<?php
						}

					endwhile;
				}

				wp_reset_query();
				?>
		</select>
		</td>
	</tr>

<?php

}
add_action( 'product_cat_edit_form_fields', 'lcwoo_edit_category_and_tag', 10, 2 );
add_action( 'product_tag_edit_form_fields', 'lcwoo_edit_category_and_tag', 10, 2 );

/**
 * ----------------------------------------------------------------------
 * Save templates category and tag in the Live Composer
 * Products -> Categories and Products -> Tags
 *
 * @param string $term_id Get current term id.
 */
function lcwoo_save_category_and_tag( $term_id ) {
	if ( isset( $_POST['lc_template'] ) ) {
		if ( ' ' === $_POST['lc_template'] ) {
			$type = 'dslc_templates';
			$args = array(
				'post_type' => $type,
				'post_status' => 'publish',
				'posts_per_page' => -1,
				'ignore_sticky_posts' => 1,
				'meta_query' => array(
			  		array(
			  			'key' => 'dslc_template_for',
			  			'value' => 'product_archive',
			  		),
			  		array(
			  			'key' => 'dslc_template_type',
			  			'value' => 'default',
			  		),
			  	),
				'orderby' => 'none',
				'order' => 'DESC',
			);
			$my_query = null;
			$my_query = new WP_Query( $args );
			if ( $my_query->have_posts() ) {
				while ( $my_query->have_posts() ) : $my_query->the_post();
					$template_id = get_the_ID();
				endwhile;
			}
			wp_reset_query();

			update_woocommerce_term_meta( $term_id, 'lc_template', $template_id, $unique = false );
		} else {
			update_woocommerce_term_meta( $term_id, 'lc_template', $_POST['lc_template'], $unique = false );
		}
	}
}
add_action( 'edit_term', 'lcwoo_save_category_and_tag', 10, 2 );
add_action( 'created_term', 'lcwoo_save_category_and_tag', 10, 2 );
