<?php
/**
 * Module Listing
 *
 * @package Live Composer - WooCommerce integration
 */

// Prevent direct access to the file.
if ( ! defined( 'ABSPATH' ) ) {
	header( 'HTTP/1.0 403 Forbidden' );
	exit;
}

/**
 * Module Class
 */
class LCWoo_Listing extends DSLC_Module {

	/**
	 * Unique module id
	 *
	 * @var string
	 */
	var $module_id;

	/**
	 * Module label to show in the page builder
	 *
	 * @var string
	 */
	var $module_title;

	/**
	 * Module icon name (FontAwesome)
	 *
	 * @var string
	 */
	var $module_icon;

	/**
	 * Section in the modules panel that includes this module
	 *
	 * @var string
	 */
	var $module_category;

	/**
	 * Exclude from main listing
	 *
	 * @var string
	 */
	var $exclude_from_main_listing;

	/**
	 * Construct
	 */
	function __construct() {

		$this->module_id = 'LCWoo_Listing';
		$this->module_title = __( 'Listing', 'lc-woo-integration' );
		$this->module_icon = 'th';
		$this->module_category = 'Woo Shop';
		$this->exclude_from_main_listing = true;
	}

	/**
	 * Options
	 */
	function options() {

		$dslc_options = array(

			array(
				'label' => __( 'Show On', 'lc-woo-integration' ),
				'id' => 'css_show_on',
				'std' => 'desktop tablet phone',
				'type' => 'checkbox',
				'choices' => array(
					array(
						'label' => __( 'Desktop', 'lc-woo-integration' ),
						'value' => 'desktop',
					),
					array(
						'label' => __( 'Tablet', 'lc-woo-integration' ),
						'value' => 'tablet',
					),
					array(
						'label' => __( 'Phone', 'lc-woo-integration' ),
						'value' => 'phone',
					),
				),
			),
			array(
				'label' => __( 'Posts Per Page', 'lc-woo-integration' ),
				'id' => 'per_page',
				'std' => 'custom_per_page',
				'type' => 'select',
				'choices' => array(
					array(
						'label' => __( 'Default', 'lc-woo-integration' ),
						'value' => 'default_per_page',
					),
					array(
						'label' => __( 'Custom', 'lc-woo-integration' ),
						'value' => 'custom_per_page',
					),
				),
				'dependent_controls' => array(
					'custom_per_page' => 'amount',
				),
			),
			array(
				'label' => __( 'Custom Posts Per Page', 'lc-woo-integration' ),
				'id' => 'amount',
				'std' => '8',
				'type' => 'text',
			),
			array(
				'label' => __( 'Items Per Row', 'lc-woo-integration' ),
				'id' => 'columns',
				'std' => '4',
				'type' => 'select',
				'choices' => array(
					array(
						'label' => __( '1', 'lc-woo-integration' ),
						'value' => '1',
					),
					array(
						'label' => __( '2', 'lc-woo-integration' ),
						'value' => '2',
					),
					array(
						'label' => __( '3', 'lc-woo-integration' ),
						'value' => '3',
					),
					array(
						'label' => __( '4', 'lc-woo-integration' ),
						'value' => '4',
					),
					array(
						'label' => __( '5', 'lc-woo-integration' ),
						'value' => '5',
					),
					array(
						'label' => __( '6', 'lc-woo-integration' ),
						'value' => '6',
					),
				),
			),

			/**
			 * General
			 */

			array(
				'label' => __( 'Elements', 'live-composer-page-builder' ),
				'id' => 'elements',
				'std' => 'result sort sale title rating cost pagination',
				'type' => 'checkbox',
				'choices' => array(
					array(
						'label' => __( 'Result', 'live-composer-page-builder' ),
						'value' => 'result',
					),
					array(
						'label' => __( 'Sort', 'live-composer-page-builder' ),
						'value' => 'sort',
					),
					array(
						'label' => __( 'Sale', 'live-composer-page-builder' ),
						'value' => 'sale',
					),
					array(
						'label' => __( 'Title', 'live-composer-page-builder' ),
						'value' => 'title',
					),
					array(
						'label' => __( 'Rating', 'live-composer-page-builder' ),
						'value' => 'rating',
					),
					array(
						'label' => __( 'Cost', 'live-composer-page-builder' ),
						'value' => 'cost',
					),
					array(
						'label' => __( 'Pagination', 'live-composer-page-builder' ),
						'value' => 'pagination',
					),
				),
				'section' => 'styling',
			),
			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_general_bg_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
			),
			array(
				'label' => __( 'Border Color', 'lc-woo-integration' ),
				'id' => 'css_general_border_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing',
				'affect_on_change_rule' => 'border-color',
				'section' => 'styling',
			),
			array(
				'label' => __( 'Border Width', 'lc-woo-integration' ),
				'id' => 'css_general_border_width',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing',
				'affect_on_change_rule' => 'border-width',
				'section' => 'styling',
				'ext' => 'px',
			),
			array(
				'label' => __( 'Borders', 'lc-woo-integration' ),
				'id' => 'css_general_border_trbl',
				'std' => 'top right bottom left',
				'type' => 'checkbox',
				'choices' => array(
					array(
						'label' => __( 'Top', 'lc-woo-integration' ),
						'value' => 'top',
					),
					array(
						'label' => __( 'Right', 'lc-woo-integration' ),
						'value' => 'right',
					),
					array(
						'label' => __( 'Bottom', 'lc-woo-integration' ),
						'value' => 'bottom',
					),
					array(
						'label' => __( 'Left', 'lc-woo-integration' ),
						'value' => 'left',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing',
				'affect_on_change_rule' => 'border-style',
				'section' => 'styling',
			),
			array(
				'label' => __( 'Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_general_padding_vertical',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'styling',
				'ext' => 'px',
			),
			array(
				'label' => __( 'Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_general_padding_horizontal',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'styling',
				'ext' => 'px',
			),
			array(
				'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_general_margin_bottom',
				'std' => '40',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'styling',
				'ext' => 'px',
			),

			/**
			 * Image
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_image_bg_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a img',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Image', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Color', 'lc-woo-integration' ),
				'id' => 'css_image_border_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a img',
				'affect_on_change_rule' => 'border-color',
				'section' => 'styling',
				'tab' => __( 'Image', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Width', 'lc-woo-integration' ),
				'id' => 'css_image_border_width',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a img',
				'affect_on_change_rule' => 'border-width',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Image', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Borders', 'lc-woo-integration' ),
				'id' => 'css_image_border_trbl',
				'std' => 'top right bottom left',
				'type' => 'checkbox',
				'choices' => array(
					array(
						'label' => __( 'Top', 'lc-woo-integration' ),
						'value' => 'top',
					),
					array(
						'label' => __( 'Right', 'lc-woo-integration' ),
						'value' => 'right',
					),
					array(
						'label' => __( 'Bottom', 'lc-woo-integration' ),
						'value' => 'bottom',
					),
					array(
						'label' => __( 'Left', 'lc-woo-integration' ),
						'value' => 'left',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a img',
				'affect_on_change_rule' => 'border-style',
				'section' => 'styling',
				'tab' => __( 'Image', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Radius - Top', 'lc-woo-integration' ),
				'id' => 'css_image_border_radius_top',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a img',
				'affect_on_change_rule' => 'border-top-left-radius,border-top-right-radius',
				'section' => 'styling',
				'tab' => __( 'Image', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Border Radius - Bottom', 'lc-woo-integration' ),
				'id' => 'css_image_border_radius_bottom',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a img',
				'affect_on_change_rule' => 'border-bottom-left-radius,border-bottom-right-radius',
				'section' => 'styling',
				'tab' => __( 'Image', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_image_margin_bottom',
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a img',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Image', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_image_padding_vertical',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a img',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Image', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_image_padding_horizontal',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a img',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Image', 'lc-woo-integration' ),
			),

			/**
			 * Title
			 */

			array(
				'label' => __( 'Color', 'lc-woo-integration' ),
				'id' => 'css_title_color',
				'std' => '#484C51',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a h3',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Size', 'lc-woo-integration' ),
				'id' => 'css_title_font_size',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a h3',
				'affect_on_change_rule' => 'font-size',
				'section' => 'styling',
				'tab' => __( 'Title', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Font Weight', 'lc-woo-integration' ),
				'id' => 'css_title_font_weight',
				'std' => '400',
				'type' => 'select',
				'choices' => array(
					array(
						'label' => '100 - Thin',
						'value' => '100',
					),
					array(
						'label' => '200 - Extra Light',
						'value' => '200',
					),
					array(
						'label' => '300 - Light',
						'value' => '300',
					),
					array(
						'label' => '400 - Normal',
						'value' => '400',
					),
					array(
						'label' => '500 - Medium',
						'value' => '500',
					),
					array(
						'label' => '600 - Semi Bold',
						'value' => '600',
					),
					array(
						'label' => '700 - Bold',
						'value' => '700',
					),
					array(
						'label' => '800 - Extra Bold',
						'value' => '800',
					),
					array(
						'label' => '900 - Black',
						'value' => '900',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a h3',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'tab' => __( 'Title', 'lc-woo-integration' ),
				'ext' => '',
			),
			array(
				'label' => __( 'Font Family', 'lc-woo-integration' ),
				'id' => 'css_title_font_family',
				'std' => '',
				'type' => 'font',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a h3',
				'affect_on_change_rule' => 'font-family',
				'section' => 'styling',
				'tab' => __( 'Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Line Height', 'lc-woo-integration' ),
				'id' => 'css_title_line_height',
				'std' => '22',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a h3',
				'affect_on_change_rule' => 'line-height',
				'section' => 'styling',
				'tab' => __( 'Title', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_title_margin_bottom',
				'std' => '5',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a h3',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'styling',
				'tab' => __( 'Title', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_title_padding_vertical',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a h3',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Text Transform', 'lc-woo-integration' ),
				'id' => 'css_title_text_transform',
				'std' => 'none',
				'type' => 'select',
				'choices' => array(
					array(
						'label' => __( 'None', 'lc-woo-integration' ),
						'value' => 'none',
					),
					array(
						'label' => __( 'Capitalize', 'lc-woo-integration' ),
						'value' => 'capitalize',
					),
					array(
						'label' => __( 'Uppercase', 'lc-woo-integration' ),
						'value' => 'uppercase',
					),
					array(
						'label' => __( 'Lowercase', 'lc-woo-integration' ),
						'value' => 'lowercase',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a h3',
				'affect_on_change_rule' => 'text-transform',
				'section' => 'styling',
				'tab' => __( 'Title', 'lc-woo-integration' ),
			),

			/**
			 * Rating
			 */

			array(
				'label' => __( 'Color', 'lc-woo-integration' ),
				'id' => 'css_rating_color',
				'std' => '#60646C',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a .star-rating',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Rating', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Color Before', 'lc-woo-integration' ),
				'id' => 'css_rating_color_before',
				'std' => 'rgb(151, 155, 163)',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a .star-rating:before',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Rating', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Size', 'lc-woo-integration' ),
				'id' => 'css_rating_font_size',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a .star-rating',
				'affect_on_change_rule' => 'font-size',
				'section' => 'styling',
				'tab' => __( 'Rating', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Line Height', 'lc-woo-integration' ),
				'id' => 'css_rating_line_height',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a .star-rating',
				'affect_on_change_rule' => 'line-height',
				'section' => 'styling',
				'tab' => __( 'Rating', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_rating_margin_bottom',
				'std' => '5',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a .star-rating',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'styling',
				'tab' => __( 'Rating', 'lc-woo-integration' ),
				'ext' => 'px',
			),

			/**
			 * Cost
			 */

			array(
				'label' => __( 'Color', 'lc-woo-integration' ),
				'id' => 'css_cost_color',
				'std' => '#60646C',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a .price',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Cost', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Color - Two', 'lc-woo-integration' ),
				'id' => 'css_cost_color_two',
				'std' => '#b7b9bd',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a .price del span',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Cost', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Size', 'lc-woo-integration' ),
				'id' => 'css_cost_font_size',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a .price',
				'affect_on_change_rule' => 'font-size',
				'section' => 'styling',
				'tab' => __( 'Cost', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Font Weight', 'lc-woo-integration' ),
				'id' => 'css_cost_font_weight_one',
				'std' => '400',
				'type' => 'select',
				'choices' => array(
					array(
						'label' => '100 - Thin',
						'value' => '100',
					),
					array(
						'label' => '200 - Extra Light',
						'value' => '200',
					),
					array(
						'label' => '300 - Light',
						'value' => '300',
					),
					array(
						'label' => '400 - Normal',
						'value' => '400',
					),
					array(
						'label' => '500 - Medium',
						'value' => '500',
					),
					array(
						'label' => '600 - Semi Bold',
						'value' => '600',
					),
					array(
						'label' => '700 - Bold',
						'value' => '700',
					),
					array(
						'label' => '800 - Extra Bold',
						'value' => '800',
					),
					array(
						'label' => '900 - Black',
						'value' => '900',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a .price',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'tab' => __( 'Cost', 'lc-woo-integration' ),
				'ext' => '',
			),
			array(
				'label' => __( 'Font Family', 'lc-woo-integration' ),
				'id' => 'css_cost_font_family',
				'std' => '',
				'type' => 'font',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a .price',
				'affect_on_change_rule' => 'font-family',
				'section' => 'styling',
				'tab' => __( 'Cost', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Line Height', 'lc-woo-integration' ),
				'id' => 'css_cost_line-height',
				'std' => '17',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a .price',
				'affect_on_change_rule' => 'line-height',
				'section' => 'styling',
				'tab' => __( 'Cost', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_cost_margin_bottom',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a .price',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'styling',
				'tab' => __( 'Cost', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_cost_padding_vertical',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a .price',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Cost', 'lc-woo-integration' ),
			),

			/**
			 * Button - Add/Select
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_button_a_and_s_bg_color',
				'std' => '#EF510E',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a.add_to_cart_button',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Button - Add/Select', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'BG:Hover Color', 'lc-woo-integration' ),
				'id' => 'css_button_a_and_s_hover_bg_color',
				'std' => '#f68150',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a.add_to_cart_button:hover',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Button - Add/Select', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Color', 'lc-woo-integration' ),
				'id' => 'css_button_a_and_s_border_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a.add_to_cart_button',
				'affect_on_change_rule' => 'border-color',
				'section' => 'styling',
				'tab' => __( 'Button - Add/Select', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Width', 'lc-woo-integration' ),
				'id' => 'css_button_a_and_s_border_width',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a.add_to_cart_button',
				'affect_on_change_rule' => 'border-width',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Button - Add/Select', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Borders', 'lc-woo-integration' ),
				'id' => 'css_button_a_and_s_border_trbl',
				'std' => 'top right bottom left',
				'type' => 'checkbox',
				'choices' => array(
					array(
						'label' => __( 'Top', 'lc-woo-integration' ),
						'value' => 'top',
					),
					array(
						'label' => __( 'Right', 'lc-woo-integration' ),
						'value' => 'right',
					),
					array(
						'label' => __( 'Bottom', 'lc-woo-integration' ),
						'value' => 'bottom',
					),
					array(
						'label' => __( 'Left', 'lc-woo-integration' ),
						'value' => 'left',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a.add_to_cart_button',
				'affect_on_change_rule' => 'border-style',
				'section' => 'styling',
				'tab' => __( 'Button - Add/Select', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Radius - Top', 'lc-woo-integration' ),
				'id' => 'css_button_a_and_s_border_radius_top',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a.add_to_cart_button',
				'affect_on_change_rule' => 'border-top-left-radius,border-top-right-radius',
				'section' => 'styling',
				'tab' => __( 'Button - Add/Select', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Border Radius - Bottom', 'lc-woo-integration' ),
				'id' => 'css_button_a_and_s_border_radius_bottom',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a.add_to_cart_button',
				'affect_on_change_rule' => 'border-bottom-left-radius,border-bottom-right-radius',
				'section' => 'styling',
				'tab' => __( 'Button - Add/Select', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Color', 'lc-woo-integration' ),
				'id' => 'css_button_a_and_s_color',
				'std' => '#FFFFFF',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a.add_to_cart_button',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Button - Add/Select', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Size', 'lc-woo-integration' ),
				'id' => 'css_button_a_and_s_font_size',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a.add_to_cart_button',
				'affect_on_change_rule' => 'font-size',
				'section' => 'styling',
				'tab' => __( 'Button - Add/Select', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Font Weight', 'lc-woo-integration' ),
				'id' => 'css_button_a_and_s_font_weight',
				'std' => '400',
				'type' => 'select',
				'choices' => array(
					array(
						'label' => '100 - Thin',
						'value' => '100',
					),
					array(
						'label' => '200 - Extra Light',
						'value' => '200',
					),
					array(
						'label' => '300 - Light',
						'value' => '300',
					),
					array(
						'label' => '400 - Normal',
						'value' => '400',
					),
					array(
						'label' => '500 - Medium',
						'value' => '500',
					),
					array(
						'label' => '600 - Semi Bold',
						'value' => '600',
					),
					array(
						'label' => '700 - Bold',
						'value' => '700',
					),
					array(
						'label' => '800 - Extra Bold',
						'value' => '800',
					),
					array(
						'label' => '900 - Black',
						'value' => '900',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a.add_to_cart_button',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'tab' => __( 'Button - Add/Select', 'lc-woo-integration' ),
				'ext' => '',
			),
			array(
				'label' => __( 'Font Family', 'lc-woo-integration' ),
				'id' => 'css_button_a_and_s_font_family',
				'std' => '',
				'type' => 'font',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a.add_to_cart_button',
				'affect_on_change_rule' => 'font-family',
				'section' => 'styling',
				'tab' => __( 'Button - Add/Select', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_button_a_and_s_padding_vertical',
				'std' => '12',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a.add_to_cart_button',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Button - Add/Select', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_button_a_and_s_padding_horizontal',
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a.add_to_cart_button',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Button - Add/Select', 'lc-woo-integration' ),
			),

			/**
			 * Button - View
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_button_view_bg_color',
				'std' => '#43454b',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a.added_to_cart',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Button - View', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'BG:Hover Color', 'lc-woo-integration' ),
				'id' => 'css_button_view_hover_bg_color',
				'std' => '#000000',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a.added_to_cart:hover',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Button - View', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Color', 'lc-woo-integration' ),
				'id' => 'css_button_view_border_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a.added_to_cart',
				'affect_on_change_rule' => 'border-color',
				'section' => 'styling',
				'tab' => __( 'Button - View', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Width', 'lc-woo-integration' ),
				'id' => 'css_button_view_border_width',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a.added_to_cart',
				'affect_on_change_rule' => 'border-width',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Button - View', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Borders', 'lc-woo-integration' ),
				'id' => 'css_button_view_border_trbl',
				'std' => 'top right bottom left',
				'type' => 'checkbox',
				'choices' => array(
					array(
						'label' => __( 'Top', 'lc-woo-integration' ),
						'value' => 'top',
					),
					array(
						'label' => __( 'Right', 'lc-woo-integration' ),
						'value' => 'right',
					),
					array(
						'label' => __( 'Bottom', 'lc-woo-integration' ),
						'value' => 'bottom',
					),
					array(
						'label' => __( 'Left', 'lc-woo-integration' ),
						'value' => 'left',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a.added_to_cart',
				'affect_on_change_rule' => 'border-style',
				'section' => 'styling',
				'tab' => __( 'Button - View', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Radius - Top', 'lc-woo-integration' ),
				'id' => 'css_button_view_border_radius_top',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a.added_to_cart',
				'affect_on_change_rule' => 'border-top-left-radius,border-top-right-radius',
				'section' => 'styling',
				'tab' => __( 'Button - View', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Border Radius - Bottom', 'lc-woo-integration' ),
				'id' => 'css_button_view_border_radius_bottom',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a.added_to_cart',
				'affect_on_change_rule' => 'border-bottom-left-radius,border-bottom-right-radius',
				'section' => 'styling',
				'tab' => __( 'Button - View', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Color', 'lc-woo-integration' ),
				'id' => 'css_button_view_color',
				'std' => '#FFFFFF',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a.added_to_cart',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Button - View', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Size', 'lc-woo-integration' ),
				'id' => 'css_button_view_font_size',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a.added_to_cart',
				'affect_on_change_rule' => 'font-size',
				'section' => 'styling',
				'tab' => __( 'Button - View', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Font Weight', 'lc-woo-integration' ),
				'id' => 'css_button_view_font_weight',
				'std' => '400',
				'type' => 'select',
				'choices' => array(
					array(
						'label' => '100 - Thin',
						'value' => '100',
					),
					array(
						'label' => '200 - Extra Light',
						'value' => '200',
					),
					array(
						'label' => '300 - Light',
						'value' => '300',
					),
					array(
						'label' => '400 - Normal',
						'value' => '400',
					),
					array(
						'label' => '500 - Medium',
						'value' => '500',
					),
					array(
						'label' => '600 - Semi Bold',
						'value' => '600',
					),
					array(
						'label' => '700 - Bold',
						'value' => '700',
					),
					array(
						'label' => '800 - Extra Bold',
						'value' => '800',
					),
					array(
						'label' => '900 - Black',
						'value' => '900',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a.added_to_cart',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'tab' => __( 'Button - View', 'lc-woo-integration' ),
				'ext' => '',
			),
			array(
				'label' => __( 'Font Family', 'lc-woo-integration' ),
				'id' => 'css_button_view_font_family',
				'std' => '',
				'type' => 'font',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a.added_to_cart',
				'affect_on_change_rule' => 'font-family',
				'section' => 'styling',
				'tab' => __( 'Button - View', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_button_view_padding_vertical',
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a.added_to_cart',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Button - View', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_button_view_padding_horizontal',
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a.added_to_cart',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Button - View', 'lc-woo-integration' ),
			),

			/**
			 * Sale
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_sale_bg_color',
				'std' => '#77a464',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a .onsale',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Sale', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Color', 'lc-woo-integration' ),
				'id' => 'css_sale_border_color',
				'std' => '#77a464',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a .onsale',
				'affect_on_change_rule' => 'border-color',
				'section' => 'styling',
				'tab' => __( 'Sale', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Width', 'lc-woo-integration' ),
				'id' => 'css_sale_border_width',
				'std' => '1',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a .onsale',
				'affect_on_change_rule' => 'border-width',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Sale', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Borders', 'lc-woo-integration' ),
				'id' => 'css_sale_border_trbl',
				'std' => 'top right bottom left',
				'type' => 'checkbox',
				'choices' => array(
					array(
						'label' => __( 'Top', 'lc-woo-integration' ),
						'value' => 'top',
					),
					array(
						'label' => __( 'Right', 'lc-woo-integration' ),
						'value' => 'right',
					),
					array(
						'label' => __( 'Bottom', 'lc-woo-integration' ),
						'value' => 'bottom',
					),
					array(
						'label' => __( 'Left', 'lc-woo-integration' ),
						'value' => 'left',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a .onsale',
				'affect_on_change_rule' => 'border-style',
				'section' => 'styling',
				'tab' => __( 'Sale', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Radius', 'lc-woo-integration' ),
				'id' => 'css_sale_border_radius',
				'std' => '44',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a .onsale',
				'affect_on_change_rule' => 'border-radius',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Sale', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_sale_padding_vertical',
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a .onsale',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Sale', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_sale_padding_horizontal',
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a .onsale',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Sale', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin Top', 'lc-woo-integration' ),
				'id' => 'css_sale_margin_top',
				'std' => '-4',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a .onsale',
				'affect_on_change_rule' => 'margin-top',
				'section' => 'styling',
				'min' => -100,
				'max' => 100,
				'ext' => '%',
				'tab' => __( 'Sale', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin Right', 'lc-woo-integration' ),
				'id' => 'css_sale_margin_right',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a .onsale',
				'affect_on_change_rule' => 'margin-right',
				'section' => 'styling',
				'min' => -100,
				'max' => 100,
				'ext' => '%',
				'tab' => __( 'Sale', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Color', 'lc-woo-integration' ),
				'id' => 'css_sale_color',
				'std' => '#ffffff',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a .onsale',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Sale', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Size', 'lc-woo-integration' ),
				'id' => 'css_sale_font_size',
				'std' => '13',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a .onsale',
				'affect_on_change_rule' => 'font-size',
				'section' => 'styling',
				'tab' => __( 'Sale', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Font Weight', 'lc-woo-integration' ),
				'id' => 'css_sale_font_weight',
				'std' => '300',
				'type' => 'select',
				'choices' => array(
					array(
						'label' => '100 - Thin',
						'value' => '100',
					),
					array(
						'label' => '200 - Extra Light',
						'value' => '200',
					),
					array(
						'label' => '300 - Light',
						'value' => '300',
					),
					array(
						'label' => '400 - Normal',
						'value' => '400',
					),
					array(
						'label' => '500 - Medium',
						'value' => '500',
					),
					array(
						'label' => '600 - Semi Bold',
						'value' => '600',
					),
					array(
						'label' => '700 - Bold',
						'value' => '700',
					),
					array(
						'label' => '800 - Extra Bold',
						'value' => '800',
					),
					array(
						'label' => '900 - Black',
						'value' => '900',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a .onsale',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'tab' => __( 'Sale', 'lc-woo-integration' ),
				'ext' => '',
			),
			array(
				'label' => __( 'Font Family', 'lc-woo-integration' ),
				'id' => 'css_sale_font_family',
				'std' => '',
				'type' => 'font',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a .onsale',
				'affect_on_change_rule' => 'font-family',
				'section' => 'styling',
				'tab' => __( 'Sale', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Line Height', 'lc-woo-integration' ),
				'id' => 'css_sale_line_height',
				'std' => '26',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a .onsale',
				'affect_on_change_rule' => 'line-height',
				'section' => 'styling',
				'tab' => __( 'Sale', 'lc-woo-integration' ),
				'ext' => 'px',
			),

			/**
			 * Sort
			 */

			array(
				'label' => __( 'Color', 'lc-woo-integration' ),
				'id' => 'css_sort_color',
				'std' => '#60646C',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-result-count',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Sort', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Size', 'lc-woo-integration' ),
				'id' => 'css_sort_font_size',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-result-count',
				'affect_on_change_rule' => 'font-size',
				'section' => 'styling',
				'tab' => __( 'Sort', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Font Weight', 'lc-woo-integration' ),
				'id' => 'css_sort_font_weight',
				'std' => '300',
				'type' => 'select',
				'choices' => array(
					array(
						'label' => '100 - Thin',
						'value' => '100',
					),
					array(
						'label' => '200 - Extra Light',
						'value' => '200',
					),
					array(
						'label' => '300 - Light',
						'value' => '300',
					),
					array(
						'label' => '400 - Normal',
						'value' => '400',
					),
					array(
						'label' => '500 - Medium',
						'value' => '500',
					),
					array(
						'label' => '600 - Semi Bold',
						'value' => '600',
					),
					array(
						'label' => '700 - Bold',
						'value' => '700',
					),
					array(
						'label' => '800 - Extra Bold',
						'value' => '800',
					),
					array(
						'label' => '900 - Black',
						'value' => '900',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-result-count',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'tab' => __( 'Sort', 'lc-woo-integration' ),
				'ext' => '',
			),
			array(
				'label' => __( 'Line Height', 'lc-woo-integration' ),
				'id' => 'css_sort_line-height',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-result-count',
				'affect_on_change_rule' => 'line-height',
				'section' => 'styling',
				'tab' => __( 'Sort', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Font Family', 'lc-woo-integration' ),
				'id' => 'css_sort_font_family',
				'std' => '',
				'type' => 'font',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-result-count',
				'affect_on_change_rule' => 'font-family',
				'section' => 'styling',
				'tab' => __( 'Sort', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_sort_padding_vertical',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-result-count',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Sort', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_sort_padding_horizontal',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-result-count',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Sort', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_sort_margin_bottom',
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-result-count',
				'affect_on_change_rule' => 'margin-bottom',
				'tab' => __( 'Sort', 'lc-woo-integration' ),
				'section' => 'styling',
				'ext' => 'px',
			),

			/**
			 * Sort > Select
			 */

			array(
				'label' => __( 'Border Color', 'lc-woo-integration' ),
				'id' => 'css_sort_select_border_color',
				'std' => '#DCDDDD',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-ordering select',
				'affect_on_change_rule' => 'border-color',
				'section' => 'styling',
				'tab' => __( 'Sort > Select', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Width', 'lc-woo-integration' ),
				'id' => 'css_sort_select_border_width',
				'std' => '1',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-ordering select',
				'affect_on_change_rule' => 'border-width',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Sort > Select', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Borders', 'lc-woo-integration' ),
				'id' => 'css_sort_select_border_trbl',
				'std' => 'top right bottom left',
				'type' => 'checkbox',
				'choices' => array(
					array(
						'label' => __( 'Top', 'lc-woo-integration' ),
						'value' => 'top',
					),
					array(
						'label' => __( 'Right', 'lc-woo-integration' ),
						'value' => 'right',
					),
					array(
						'label' => __( 'Bottom', 'lc-woo-integration' ),
						'value' => 'bottom',
					),
					array(
						'label' => __( 'Left', 'lc-woo-integration' ),
						'value' => 'left',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-ordering select',
				'affect_on_change_rule' => 'border-style',
				'section' => 'styling',
				'tab' => __( 'Sort > Select', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Color', 'lc-woo-integration' ),
				'id' => 'css_sort_select_color',
				'std' => '#000000',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-ordering select',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Sort > Select', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Size', 'lc-woo-integration' ),
				'id' => 'css_sort_select_font_size',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-ordering select',
				'affect_on_change_rule' => 'font-size',
				'section' => 'styling',
				'tab' => __( 'Sort > Select', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Font Weight', 'lc-woo-integration' ),
				'id' => 'css_sort_select_font_weight',
				'std' => '300',
				'type' => 'select',
				'choices' => array(
					array(
						'label' => '100 - Thin',
						'value' => '100',
					),
					array(
						'label' => '200 - Extra Light',
						'value' => '200',
					),
					array(
						'label' => '300 - Light',
						'value' => '300',
					),
					array(
						'label' => '400 - Normal',
						'value' => '400',
					),
					array(
						'label' => '500 - Medium',
						'value' => '500',
					),
					array(
						'label' => '600 - Semi Bold',
						'value' => '600',
					),
					array(
						'label' => '700 - Bold',
						'value' => '700',
					),
					array(
						'label' => '800 - Extra Bold',
						'value' => '800',
					),
					array(
						'label' => '900 - Black',
						'value' => '900',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-ordering select',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'tab' => __( 'Sort > Select', 'lc-woo-integration' ),
				'ext' => '',
			),
			array(
				'label' => __( 'Font Family', 'lc-woo-integration' ),
				'id' => 'css_sort_select_font_family',
				'std' => '',
				'type' => 'font',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-ordering select',
				'affect_on_change_rule' => 'font-family',
				'section' => 'styling',
				'tab' => __( 'Sort > Select', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_sort_select_padding_vertical',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-ordering',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Sort > Select', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_sort_select_padding_horizontal',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-ordering',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Sort > Select', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_sort_select_margin_bottom',
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-ordering select',
				'affect_on_change_rule' => 'margin-bottom',
				'tab' => __( 'Sort > Select', 'lc-woo-integration' ),
				'section' => 'styling',
				'ext' => 'px',
			),

			/**
			 * Pagination
			 */

			array(
				'label' => 'Container - Align',
				'id' => 'css_pagination_align',
				'std' => 'center',
				'type' => 'text_align',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-pagination',
				'affect_on_change_rule' => 'text-align',
				'section' => 'styling',
				'tab' => __( 'Pagination', 'lc-woo-integration' ),
			),
			array(
				'label' => 'Container - Padding Vertical',
				'id' => 'css_pagination_padding_vertical',
				'min' => 0,
				'max' => 600,
				'increment' => 1,
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-pagination',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Pagination', 'lc-woo-integration' ),
			),
			array(
				'label' => 'Container - Padding Horizontal',
				'id' => 'css_pagination_padding_horizontal',
				'min' => 0,
				'max' => 1000,
				'increment' => 1,
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-pagination',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Pagination', 'lc-woo-integration' ),
			),
			array(
				'label' => 'Item - BG Color',
				'id' => 'css_pagination_item_bg_color',
				'std' => '#f9f9f9',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-pagination li a',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Pagination', 'lc-woo-integration' ),
			),
			array(
				'label' => 'Item - Active - BG Color',
				'id' => 'css_pagination_item_bg_color_active',
				'std' => '#2c2d33',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-pagination li span.current',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Pagination', 'lc-woo-integration' ),
			),
			array(
				'label' => 'Item - Border Color',
				'id' => 'css_pagination_item_border_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-pagination li .page-numbers',
				'affect_on_change_rule' => 'border-color',
				'section' => 'styling',
				'tab' => __( 'Pagination', 'lc-woo-integration' ),
			),
			array(
				'label' => 'Item - Border Width',
				'id' => 'css_pagination_item_border_width',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-pagination li .page-numbers',
				'affect_on_change_rule' => 'border-width',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Pagination', 'lc-woo-integration' ),
			),
			array(
				'label' => 'Item - Borders',
				'id' => 'css_pagination_item_border_trbl',
				'std' => 'top right bottom left',
				'type' => 'checkbox',
				'choices' => array(
					array(
						'label' => 'Top',
						'value' => 'top',
					),
					array(
						'label' => 'Right',
						'value' => 'right',
					),
					array(
						'label' => 'Bottom',
						'value' => 'bottom',
					),
					array(
						'label' => 'Left',
						'value' => 'left',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-pagination li .page-numbers',
				'affect_on_change_rule' => 'border-style',
				'section' => 'styling',
				'tab' => __( 'Pagination', 'lc-woo-integration' ),
			),
			array(
				'label' => 'Item - Border Radius',
				'id' => 'css_pagination_item_border_radius',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-pagination li .page-numbers',
				'affect_on_change_rule' => 'border-radius',
				'min' => 0,
				'max' => 100,
				'increment' => 1,
				'section' => 'styling',
				'tab' => __( 'Pagination', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => 'Item - Color',
				'id' => 'css_pagination_item_color',
				'std' => '#43454b',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-pagination li a',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Pagination', 'lc-woo-integration' ),
			),
			array(
				'label' => 'Item - Active - Color',
				'id' => 'css_pagination_item_color_active',
				'std' => '#ffffff',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-pagination li .page-numbers.current',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Pagination', 'lc-woo-integration' ),
			),
			array(
				'label' => 'Item - Font Size',
				'id' => 'css_pagination_item_font_size',
				'min' => 0,
				'max' => 100,
				'increment' => 1,
				'std' => '11',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-pagination li .page-numbers',
				'affect_on_change_rule' => 'font-size',
				'section' => 'styling',
				'tab' => __( 'Pagination', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => 'Item - Font Weight',
				'id' => 'css_pagination_item_font_weight',
				'std' => '700',
				'type' => 'select',
				'choices' => array(
					array(
						'label' => '100 - Thin',
						'value' => '100',
					),
					array(
						'label' => '200 - Extra Light',
						'value' => '200',
					),
					array(
						'label' => '300 - Light',
						'value' => '300',
					),
					array(
						'label' => '400 - Normal',
						'value' => '400',
					),
					array(
						'label' => '500 - Medium',
						'value' => '500',
					),
					array(
						'label' => '600 - Semi Bold',
						'value' => '600',
					),
					array(
						'label' => '700 - Bold',
						'value' => '700',
					),
					array(
						'label' => '800 - Extra Bold',
						'value' => '800',
					),
					array(
						'label' => '900 - Black',
						'value' => '900',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-pagination li .page-numbers',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'tab' => __( 'Pagination', 'lc-woo-integration' ),
				'ext' => '',
			),
			array(
				'label' => 'Item - Font Family',
				'id' => 'css_pagination_item_font_family',
				'std' => '',
				'type' => 'font',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-pagination li .page-numbers',
				'affect_on_change_rule' => 'font-family',
				'section' => 'styling',
				'tab' => __( 'Pagination', 'lc-woo-integration' ),
			),
			array(
				'label' => 'Item - Padding Vertical',
				'id' => 'css_pagination_item_padding_vertical',
				'min' => 0,
				'max' => 600,
				'increment' => 1,
				'std' => '12',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-pagination li .page-numbers',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Pagination', 'lc-woo-integration' ),
			),
			array(
				'label' => 'Item - Padding Horizontal',
				'id' => 'css_pagination_item_padding_horizontal',
				'min' => 0,
				'max' => 1000,
				'increment' => 1,
				'std' => '12',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-pagination li .page-numbers',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Pagination', 'lc-woo-integration' ),
			),
			array(
				'label' => 'Item - Spacing',
				'id' => 'css_pagination_item_spacing',
				'std' => '4',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-pagination li',
				'affect_on_change_rule' => 'margin-right',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Pagination', 'lc-woo-integration' ),
			),

			/**
			 * Info
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_info_bg_color',
				'std' => '#3D9CD2',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-info',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Info', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Color', 'lc-woo-integration' ),
				'id' => 'css_info_border_color',
				'std' => '#3384B2',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-info',
				'affect_on_change_rule' => 'border-color',
				'section' => 'styling',
				'tab' => __( 'Info', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Width', 'lc-woo-integration' ),
				'id' => 'css_info_border_width',
				'std' => '1',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-info',
				'affect_on_change_rule' => 'border-width',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Info', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Radius', 'lc-woo-integration' ),
				'id' => 'css_info_border_radius',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-info',
				'affect_on_change_rule' => 'border-radius',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Info', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Borders', 'lc-woo-integration' ),
				'id' => 'css_info_border_trbl',
				'std' => 'top right bottom left',
				'type' => 'checkbox',
				'choices' => array(
					array(
						'label' => __( 'Top', 'lc-woo-integration' ),
						'value' => 'top',
					),
					array(
						'label' => __( 'Right', 'lc-woo-integration' ),
						'value' => 'right',
					),
					array(
						'label' => __( 'Bottom', 'lc-woo-integration' ),
						'value' => 'bottom',
					),
					array(
						'label' => __( 'Left', 'lc-woo-integration' ),
						'value' => 'left',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-info',
				'affect_on_change_rule' => 'border-style',
				'section' => 'styling',
				'tab' => __( 'Info', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Color', 'lc-woo-integration' ),
				'id' => 'css_info_color',
				'std' => '#ffffff',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-info',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Info', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Size', 'lc-woo-integration' ),
				'id' => 'css_info_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-info',
				'affect_on_change_rule' => 'font-size',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Info', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Weight', 'lc-woo-integration' ),
				'id' => 'css_info_font_weight',
				'std' => '300',
				'type' => 'select',
				'choices' => array(
					array(
						'label' => '100 - Thin',
						'value' => '100',
					),
					array(
						'label' => '200 - Extra Light',
						'value' => '200',
					),
					array(
						'label' => '300 - Light',
						'value' => '300',
					),
					array(
						'label' => '400 - Normal',
						'value' => '400',
					),
					array(
						'label' => '500 - Medium',
						'value' => '500',
					),
					array(
						'label' => '600 - Semi Bold',
						'value' => '600',
					),
					array(
						'label' => '700 - Bold',
						'value' => '700',
					),
					array(
						'label' => '800 - Extra Bold',
						'value' => '800',
					),
					array(
						'label' => '900 - Black',
						'value' => '900',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-info',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'ext' => '',
				'tab' => __( 'Info', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Family', 'lc-woo-integration' ),
				'id' => 'css_info_font_family',
				'std' => '',
				'type' => 'font',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-info',
				'affect_on_change_rule' => 'font-family',
				'section' => 'styling',
				'tab' => __( 'Info', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Line Height', 'lc-woo-integration' ),
				'id' => 'css_info_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-info',
				'affect_on_change_rule' => 'line-height',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Info', 'lc-woo-integration' ),
			),

			/**
			 * Responsive Tablet
			 */

			array(
				'label' => __( 'Responsive Styling', 'lc-woo-integration' ),
				'id' => 'css_res_t',
				'std' => 'disabled',
				'type' => 'select',
				'choices' => array(
					array(
						'label' => __( 'Disabled', 'lc-woo-integration' ),
						'value' => 'disabled',
					),
					array(
						'label' => __( 'Enabled', 'lc-woo-integration' ),
						'value' => 'enabled',
					),
				),
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_t_general_padding_vertical',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_t_general_padding_horizontal',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_t_general_margin_bottom',
				'std' => '30',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Image - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_t_image_margin_bottom',
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a img',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Image - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_t_image_padding_vertical',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a img',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Image - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_t_image_padding_horizontal',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a img',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Title - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_title_font_size',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a h3',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Title - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_title_line_height',
				'std' => '22',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a h3',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Title - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_t_title_margin_bottom',
				'std' => '5',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a h3',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Title - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_t_title_padding_vertical',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a h3',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Rating - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_rating_font_size',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a .star-rating',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Rating - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_rating_line_height',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a .star-rating',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Rating - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_t_rating_margin_bottom',
				'std' => '5',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a .star-rating',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Cost - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_cost_font_size',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a .price',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Cost - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_cost_line-height',
				'std' => '17',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a .price',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Cost - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_t_cost_margin_bottom',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a .price',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Cost - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_t_cost_padding_vertical',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a .price',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Button > Add/Select - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_button_a_and_s_font_size',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a.add_to_cart_button',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Button > Add/Select - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_t_button_a_and_s_padding_vertical',
				'std' => '12',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a.add_to_cart_button',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Button > Add/Select - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_t_button_a_and_s_padding_horizontal',
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a.add_to_cart_button',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Button > View - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_button_view_font_size',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a.added_to_cart',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Button > View - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_t_button_view_padding_vertical',
				'std' => '11',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a.added_to_cart',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Button > View - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_t_button_view_padding_horizontal',
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a.added_to_cart',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Sale - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_t_sale_padding_vertical',
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a .onsale',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Sale - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_t_sale_padding_horizontal',
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a .onsale',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Sale - Margin Top', 'lc-woo-integration' ),
				'id' => 'css_res_t_sale_margin_top',
				'std' => '-4',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a .onsale',
				'affect_on_change_rule' => 'margin-top',
				'section' => 'responsive',
				'min' => -100,
				'max' => 100,
				'ext' => '%',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Sale - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_sale_font_size',
				'std' => '13',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a .onsale',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Sale - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_sale_line_height',
				'std' => '26',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a .onsale',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Sort - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_sort_font_size',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-result-count',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Sort - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_sort_line-height',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-result-count',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Sort - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_t_sort_padding_vertical',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-result-count',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Sort - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_t_sort_padding_horizontal',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-result-count',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Sort - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_t_sort_margin_bottom',
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-result-count',
				'affect_on_change_rule' => 'margin-bottom',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'section' => 'responsive',
				'ext' => 'px',
			),
			array(
				'label' => __( 'Sort > Select - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_sort_select_font_size',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-ordering select',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Sort > Select - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_t_sort_select_padding_vertical',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-ordering',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Sort > Select - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_t_sort_select_padding_horizontal',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-ordering',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Sort > Select - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_t_sort_select_margin_bottom',
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-ordering select',
				'affect_on_change_rule' => 'margin-bottom',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'section' => 'responsive',
				'ext' => 'px',
			),
			array(
				'label' => 'Pagination > Container - Padding Vertical',
				'id' => 'css_res_t_pagination_padding_vertical',
				'min' => 0,
				'max' => 600,
				'increment' => 1,
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-pagination',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => 'Pagination > Container - Padding Horizontal',
				'id' => 'css_res_t_pagination_padding_horizontal',
				'min' => 0,
				'max' => 1000,
				'increment' => 1,
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-pagination',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => 'Pagination > Item - Font Size',
				'id' => 'css_res_t_pagination_item_font_size',
				'min' => 0,
				'max' => 100,
				'increment' => 1,
				'std' => '11',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-pagination li .page-numbers',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => 'Pagination > Item - Padding Vertical',
				'id' => 'css_res_t_pagination_item_padding_vertical',
				'min' => 0,
				'max' => 600,
				'increment' => 1,
				'std' => '12',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-pagination li .page-numbers',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => 'Pagination > Item - Padding Horizontal',
				'id' => 'css_res_t_pagination_item_padding_horizontal',
				'min' => 0,
				'max' => 1000,
				'increment' => 1,
				'std' => '12',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-pagination li .page-numbers',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => 'Pagination > Item - Spacing',
				'id' => 'css_res_t_pagination_item_spacing',
				'std' => '4',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-pagination li',
				'affect_on_change_rule' => 'margin-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_info_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-info',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_info_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-info',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),

			/**
			 * Responsive Phone
			 */

			array(
				'label' => __( 'Responsive Styling', 'lc-woo-integration' ),
				'id' => 'css_res_p',
				'std' => 'disabled',
				'type' => 'select',
				'choices' => array(
					array(
						'label' => __( 'Disabled', 'lc-woo-integration' ),
						'value' => 'disabled',
					),
					array(
						'label' => __( 'Enabled', 'lc-woo-integration' ),
						'value' => 'enabled',
					),
				),
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_p_general_padding_vertical',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_p_general_padding_horizontal',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_p_general_margin_bottom',
				'std' => '30',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Image - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_p_image_margin_bottom',
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a img',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Image - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_p_image_padding_vertical',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a img',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Image - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_p_image_padding_horizontal',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a img',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Title - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_title_font_size',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a h3',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Title - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_title_line_height',
				'std' => '22',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a h3',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Title - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_p_title_margin_bottom',
				'std' => '5',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a h3',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Title - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_p_title_padding_vertical',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a h3',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Rating - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_rating_font_size',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a .star-rating',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Rating - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_rating_line_height',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a .star-rating',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Rating - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_p_rating_margin_bottom',
				'std' => '5',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a .star-rating',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Cost - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_cost_font_size',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a .price',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Cost - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_cost_line-height',
				'std' => '17',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a .price',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Cost - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_p_cost_margin_bottom',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a .price',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Cost - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_p_cost_padding_vertical',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a .price',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Button > Add/Select - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_button_a_and_s_font_size',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a.add_to_cart_button',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Button > Add/Select - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_p_button_a_and_s_padding_vertical',
				'std' => '12',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a.add_to_cart_button',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Button > Add/Select - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_p_button_a_and_s_padding_horizontal',
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a.add_to_cart_button',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Button > View - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_button_view_font_size',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a.added_to_cart',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Button > View - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_p_button_view_padding_vertical',
				'std' => '11',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a.added_to_cart',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Button > View - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_p_button_view_padding_horizontal',
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a.added_to_cart',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Sale - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_p_sale_padding_vertical',
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a .onsale',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Sale - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_p_sale_padding_horizontal',
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a .onsale',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Sale - Margin Top', 'lc-woo-integration' ),
				'id' => 'css_res_p_sale_margin_top',
				'std' => '-4',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a .onsale',
				'affect_on_change_rule' => 'margin-top',
				'section' => 'responsive',
				'min' => -100,
				'max' => 100,
				'ext' => '%',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Sale - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_sale_font_size',
				'std' => '13',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a .onsale',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Sale - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_sale_line_height',
				'std' => '26',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing ul.products li a .onsale',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Sort - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_sort_font_size',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-result-count',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Sort - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_sort_line-height',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-result-count',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Sort - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_p_sort_padding_vertical',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-result-count',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Sort - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_p_sort_padding_horizontal',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-result-count',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Sort - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_p_sort_margin_bottom',
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-result-count',
				'affect_on_change_rule' => 'margin-bottom',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'section' => 'responsive',
				'ext' => 'px',
			),
			array(
				'label' => __( 'Sort > Select - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_sort_select_font_size',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-ordering select',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Sort > Select - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_p_sort_select_padding_vertical',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-ordering',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Sort > Select - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_p_sort_select_padding_horizontal',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-ordering',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Sort > Select - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_p_sort_select_margin_bottom',
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-ordering select',
				'affect_on_change_rule' => 'margin-bottom',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'section' => 'responsive',
				'ext' => 'px',
			),
			array(
				'label' => 'Pagination > Container - Padding Vertical',
				'id' => 'css_res_p_pagination_padding_vertical',
				'min' => 0,
				'max' => 600,
				'increment' => 1,
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-pagination',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => 'Pagination > Container - Padding Horizontal',
				'id' => 'css_res_p_pagination_padding_horizontal',
				'min' => 0,
				'max' => 1000,
				'increment' => 1,
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-pagination',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => 'Pagination > Item - Font Size',
				'id' => 'css_res_p_pagination_item_font_size',
				'min' => 0,
				'max' => 100,
				'increment' => 1,
				'std' => '11',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-pagination li .page-numbers',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => 'Pagination > Item - Padding Vertical',
				'id' => 'css_res_p_pagination_item_padding_vertical',
				'min' => 0,
				'max' => 600,
				'increment' => 1,
				'std' => '12',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-pagination li .page-numbers',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => 'Pagination > Item - Padding Horizontal',
				'id' => 'css_res_p_pagination_item_padding_horizontal',
				'min' => 0,
				'max' => 1000,
				'increment' => 1,
				'std' => '12',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-pagination li .page-numbers',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => 'Pagination > Item - Spacing',
				'id' => 'css_res_p_pagination_item_spacing',
				'std' => '4',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-pagination li',
				'affect_on_change_rule' => 'margin-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_info_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-info',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_info_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-listing .woocommerce-info',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),

		);

		$dslc_options = array_merge( $dslc_options, $this->shared_options( 'animation_options' ) );
		$dslc_options = array_merge( $dslc_options, $this->presets_options() );

		return apply_filters( 'dslc_module_options', $dslc_options, $this->module_id );

	}

	/**
	 * Module HTML output.
	 *
	 * @param  array $options Module options to fill the module template.
	 */
	function output( $options ) {

		$this->module_start( $options );

		global $dslc_active;

		?>

		<?php if ( is_shop() || is_product_category() || is_product_tag() || $dslc_active || 'dslc_templates' === get_post_type() ) { ?>

			<?php

			global $lcwoo_columns_listing;
			$lcwoo_columns_listing = $options['columns'];
			add_filter( 'loop_shop_columns', function() { global $lcwoo_columns_listing; return $lcwoo_columns_listing; } );

			?>

			<style type="text/css">
				<?php

				$elements = $options['elements'];
				if ( ! empty( $elements ) ) {
					$elements = explode( ' ', trim( $elements ) );
				} else {
					$elements = array();
				}

				if ( ! in_array( 'result', $elements ) ) {
					echo '.woo-listing .woocommerce-result-count';
					echo '{ display: none; }';
				}

				if ( ! in_array( 'sort', $elements ) ) {
					echo '.woo-listing .woocommerce-ordering';
					echo '{ display: none; }';
				}

				if ( ! in_array( 'sale', $elements ) ) {
					echo '.woo-listing .onsale';
					echo '{ display: none; }';
				}

				if ( ! in_array( 'title', $elements ) ) {
					echo '.woo-listing .products li h3';
					echo '{ display: none; }';
				}

				if ( ! in_array( 'rating', $elements ) ) {
					echo '.woo-listing .star-rating';
					echo '{ display: none !important; }';
				}

				if ( ! in_array( 'cost', $elements ) ) {
					echo '.woo-listing ul.products li .price';
					echo '{ display: none !important; }';
				}

				if ( ! in_array( 'pagination', $elements ) ) {
					echo '.woo-listing .woocommerce-pagination';
					echo '{ display: none; }';
				}

				?>
			</style>

			<div class="woo-listing">
				<div class="woocommerce columns-<?php echo $options['columns']; ?>">

				<?php

				if ( 'default_per_page' === $options['per_page'] ) {
					$options['amount'] = apply_filters( 'loop_shop_per_page', get_option( 'posts_per_page' ) );
				}

				if ( $dslc_active ) {

					if ( isset( $_GET['preview_id'] ) || isset( $_POST['dslc_url_vars']['preview_id'] ) ) {

						if ( isset( $_GET['preview_id'] ) ) {
							$get_id = $_GET['preview_id'];
						} elseif ( isset( $_POST['dslc_url_vars']['preview_id'] ) ) {
							$get_id = $_POST['dslc_url_vars']['preview_id'];
						} else {
							$get_id = '';
						}

						$term = get_term( $get_id );
						$taxonomy = $term->taxonomy;
						$slug = $term->slug;

						$args = array(
							'post_type' => 'product',
							'posts_per_page' => $options['amount'],
							'wc_query' => 'product_query',
							'taxonomy' => $taxonomy,
							'term' => $slug,
							'orderby' => 'menu_order title',
							'order' => 'ASC',
						);
						$loop = new WP_Query( $args );
					} else {

						$args = array(
							'post_type' => 'product',
							'posts_per_page' => $options['amount'],
							'wc_query' => 'product_query',
							'orderby' => 'menu_order title',
							'order' => 'ASC',
						);
						$loop = new WP_Query( $args );
					}
				} elseif ( 'dslc_templates' === get_post_type() && !is_product_category() && !is_product_tag() && !is_shop() ) {

					$args = array(
						'post_type' => 'product',
						'posts_per_page' => $options['amount'],
						'wc_query' => 'product_query',
						'orderby' => 'menu_order title',
						'order' => 'ASC',
					);
					$loop = new WP_Query( $args );
				} else {

					global $wp_query;

					$wp_query->set( 'posts_per_page', $options['amount'] );
					$wp_query->query( $wp_query->query_vars );
					$loop = $wp_query;
				}

				?>

				<?php
					/**
					 * Woocommerce_before_main_content hook.
					 *
					 * @hooked woocommerce_output_content_wrapper - 10 (outputs opening divs for the content)
					 * @hooked woocommerce_breadcrumb - 20
					 */
					remove_action( 'woocommerce_before_main_content', 'woocommerce_breadcrumb', 20, 0 );
					do_action( 'woocommerce_before_main_content' );
				?>

					<?php
						/**
						 * Woocommerce_archive_description hook.
						 *
						 * @hooked woocommerce_taxonomy_archive_description - 10
						 * @hooked woocommerce_product_archive_description - 10
						 */
						do_action( 'woocommerce_archive_description' );
					?>

					<?php if ( $loop->have_posts() ) : ?>

						<?php
						/**
						 * Woocommerce_before_shop_loop hook.
						 *
						 * @hooked woocommerce_result_count - 20
						 * @hooked woocommerce_catalog_ordering - 30
						 */
						do_action( 'woocommerce_before_shop_loop' );

						if ( $dslc_active || ( 'dslc_templates' === get_post_type() && !is_product_category() && !is_product_tag() && !is_shop() ) ) { ?>
							<p class="woocommerce-result-count">Showing 1–5 of 12 results</p>
							<form class="woocommerce-ordering" method="get">
								<select name="orderby" class="orderby">
									<option value="menu_order" selected="selected">Default sorting</option>
									<option value="popularity">Sort by popularity</option>
									<option value="rating">Sort by average rating</option>
									<option value="date">Sort by newness</option>
									<option value="price">Sort by price: low to high</option>
									<option value="price-desc">Sort by price: high to low</option>
								</select>
							</form>
						<?php }

						?>

						<?php woocommerce_product_loop_start(); ?>

							<?php woocommerce_product_subcategories(); ?>

							<?php while ( $loop->have_posts() ) : $loop->the_post(); ?>

								<?php wc_get_template_part( 'content', 'product' ); ?>

							<?php endwhile; // End of the loop. ?>

						<?php woocommerce_product_loop_end(); ?>

						<?php wp_reset_query(); ?>

						<?php
						/**
						 * Woocommerce_after_shop_loop hook.
						 *
						 * @hooked woocommerce_pagination - 10
						 */
						do_action( 'woocommerce_after_shop_loop' );
						if ( $dslc_active || ( 'dslc_templates' === get_post_type() && !is_product_category() && !is_product_tag() && !is_shop() ) ) { ?>
							<nav class="woocommerce-pagination">
								<ul class="page-numbers">
									<li><span class="page-numbers current">1</span></li>
									<li><a class="page-numbers" href="#">2</a></li>
									<li><a class="page-numbers" href="#">3</a></li>
									<li><a class="next page-numbers" href="#">→</a></li>
								</ul>
							</nav>
						<?php }
						?>

					<?php elseif ( ! woocommerce_product_subcategories( array( 'before' => woocommerce_product_loop_start( false ), 'after' => woocommerce_product_loop_end( false ) ) ) ) : ?>

						<?php wc_get_template( 'loop/no-products-found.php' ); ?>

					<?php endif; ?>

				<?php
					/**
					 * Woocommerce_after_main_content hook.
					 *
					 * @hooked woocommerce_output_content_wrapper_end - 10 (outputs closing divs for the content)
					 */
					do_action( 'woocommerce_after_main_content' );
				?>

				</div>
			</div>

		<?php } else {
			if ( current_user_can( 'manage_options' ) ) {
			?>
				<div class="dslc-notification dslc-red">
					<?php esc_html_e( 'This module is for WooCommerce pages only.', 'lc-woo-integration' ); ?>
				</div>
			<?php
			}
		}

		$this->module_end( $options );
	}
}

/**
 * Register Module
 */
add_action('dslc_hook_register_modules',
	create_function( '', 'return dslc_register_module( "LCWoo_Listing" );' )
);
